package hk.advanpro.cloud.android;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.TypeReference;

import org.apache.commons.lang3.StringUtils;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;

import hk.advanpro.cloud.android.model.CloudAddressType;
import hk.advanpro.cloud.android.model.Token;
import hk.advanpro.cloud.android.model.UserAgent;
import hk.advanpro.cloud.api.CloudApiManager;
import hk.advanpro.cloud.api.callback.ResponseErrorCallback;
import hk.advanpro.cloud.api.callback.ResponseFailureCallback;
import hk.advanpro.cloud.api.client.AdminApi;
import hk.advanpro.cloud.api.client.CDNApi;
import hk.advanpro.cloud.api.client.CMSApi;
import hk.advanpro.cloud.api.client.CloudApi;
import hk.advanpro.cloud.api.client.CourseApi;
import hk.advanpro.cloud.api.client.DDCApi;
import hk.advanpro.cloud.api.client.DevUCApi;
import hk.advanpro.cloud.api.client.HomeApi;
import hk.advanpro.cloud.api.client.MsgApi;
import hk.advanpro.cloud.api.client.OCApi;
import hk.advanpro.cloud.api.client.OSSApi;
import hk.advanpro.cloud.api.client.QCApi;
import hk.advanpro.cloud.api.client.SACApi;
import hk.advanpro.cloud.api.client.SHOPApi;
import hk.advanpro.cloud.api.client.SOCApi;
import hk.advanpro.cloud.api.client.UCApi;
import hk.advanpro.cloud.api.client.WebApi;
import hk.advanpro.cloud.api.interceptor.RequestInterceptor;
import hk.advanpro.cloud.api.interceptor.ResponseInterceptor;
import hk.advanpro.cloud.api.options.ParameterOptions;
import okhttp3.Call;
import okhttp3.Request;
import okhttp3.Response;

/**
 * 云端服务
 * Created by jalin on 2017/11/16.
 */
public class CloudService {

    // 2,0,0之后将“User-Agent”改为“X-User-Agent”
    public static final String HEAD_OPTION_USER_AGENT = "X-User-Agent";
    public static final String HEAD_OPTION_X_ACCEPT_LANGUAGE = "X-Accept-Language";
    public static final String HEAD_OPTION_AUTHORIZATION = "Authorization";

    /**
     * 云端环境
     */
    public static CloudAddressType addressType = CloudAddressType.PRODUCT;

    public static final Map<String, Class<? extends CloudApi>> API_CLASS_MAP = new TreeMap<String, Class<? extends CloudApi>>() {{
        put(UCApi.NAME, UCApi.class);
        put(DDCApi.NAME, DDCApi.class);
        put(CMSApi.NAME, CMSApi.class);
        put(AdminApi.NAME, AdminApi.class);
        put(OSSApi.NAME, OSSApi.class);
        put(CDNApi.NAME, CDNApi.class);
        put(OCApi.NAME, OCApi.class);
        put(SOCApi.NAME, SOCApi.class);
        put(SHOPApi.NAME, SHOPApi.class);
        put(HomeApi.NAME, HomeApi.class);
        put(QCApi.NAME, QCApi.class);
        put(CourseApi.NAME, CourseApi.class);
        put(DevUCApi.NAME, DevUCApi.class);
        put(MsgApi.NAME, MsgApi.class);
        put(WebApi.NAME, WebApi.class);
    }};

    private static UserAgent userAgent = null;// user agent
    private static String acceptLanguage = null;// 语言
    private static Map<String, List<String>> apiAddressMap;
    private static CloudService defaultInstance;

    private Map<Class<? extends CloudApi>, CloudApi> APIS = new HashMap<>();

    private Token token = new Token() {
        String token;

        @Override
        public String getToken() {
            return token;
        }

        @Override
        public void setToken(String token) {
            this.token = token;
        }
    };


    private ResponseFailureCallback failureInterceptor;
    private ResponseErrorCallback errorInterceptor;

    public static void initUserAgent(UserAgent userAgent) {
        CloudService.userAgent = userAgent;
    }

    public static UserAgent getUserAgent() {
        return userAgent;
    }

    /**
     * 设置语言
     *
     * @param acceptLanguage
     */
    public static void setAcceptLanguage(String acceptLanguage) {
        CloudService.acceptLanguage = acceptLanguage;

    }

    public static void initCloudAddressType(CloudAddressType type) {
        CloudService.addressType = type;
    }

    /**
     * 初始化指定地址
     *
     * @param apiUrlMap
     */
    public static void initCloudAddressUrls(Map<String, List<String>> apiUrlMap) {
        CloudService.apiAddressMap = apiUrlMap;
    }

    public static Map<String, List<String>> getDefaultApiAddress(CloudAddressType addressType) {
        String urlJsonString;
        switch (addressType) {
            case DEV://开发环境
                urlJsonString = "{'oss':['https://develop.advanpro.cn/api/oss/2.0']," +
                        "'cdn':['https://wearservice.oss-cn-shenzhen.aliyuncs.com']," +
                        "'shop':['http://dev-laf-shop.advanpro.cn/']," +
                        "'home':['https://test2-lamaze.advanpro.cn/']," +
                        "'ddc':['https://develop.advanpro.cn/api/ddc/2.0']," +
                        "'cms':['https://develop.advanpro.cn/api/cms/2.0']," +
                        "'uc':['https://develop.advanpro.cn/api/uc/2.0']," +
                        "'admin':['https://develop.advanpro.cn/api/admin/1.0']," +
                        "'soc':['https://develop.advanpro.cn/api/soc/1.0']," +
                        "'qc':['https://develop.advanpro.cn/api/ddc/2.0']," +
                        "'oc':['https://develop.advanpro.cn/api/oc/1.0']," +
                        "'course':['https://develop.advanpro.cn/api/course/1.0']," +
                        "'dev':['https://develop.advanpro.cn/api/devuc/1.0']," +
                        "'msg':['https://develop.advanpro.cn/api/msg/2.0']" +
                        "}";
                break;
            case UAT://测试环境
                urlJsonString = "{'oss':['https://test.advanpro.cn/api/oss/2.0']," +
                        "'cdn':['https://wearservice.oss-cn-shenzhen.aliyuncs.com']," +
                        "'shop':['https://test-laf-shop.advanpro.cn/']," +
                        "'home':['https://test2-lamaze.advanpro.cn/']," +
                        "'ddc':['https://test.advanpro.cn/api/ddc/2.0']," +
                        "'cms':['https://test.advanpro.cn/api/cms/2.0']," +
                        "'uc':['https://test.advanpro.cn/api/uc/2.0']," +
                        "'admin':['https://test.advanpro.cn/api/admin/1.0']," +
                        "'soc':['https://test.advanpro.cn/api/soc/1.0']," +
                        "'qc':['https://test.advanpro.cn/api/ddc/2.0']," +
                        "'oc':['https://test.advanpro.cn/api/oc/1.0']," +
                        "'course':['https://test.advanpro.cn/api/course/1.0']," +
                        "'dev':['https://test.advanpro.cn/api/devuc/1.0']," +
                        "'msg':['https://test.advanpro.cn/api/msg/2.0']" +
                        "}";
                break;
            case PRODUCT://正式环境
            default:
                urlJsonString = "{" +
                        "'ddc': ['https://api.advanpro.cn/ddc/2.0']," +
                        "'oc': ['https://api.advanpro.cn/oc/1.0']," +
                        "'cms': ['https://api.advanpro.cn/cms/2.0']," +
                        "'home':['https://test2-lamaze.advanpro.cn/']," +
                        "'admin': ['https://api.advanpro.cn/admin/1.0']," +
                        "'cdn': ['https://cdn.advanpro.cn']," +
                        "'uc': ['https://api.advanpro.cn/uc/2.0']," +
                        "'soc': ['https://api.advanpro.cn/soc/1.0']," +
                        "'qc':['https://api.advanpro.cn/ddc/2.0']," +
                        "'oss': ['https://api.advanpro.cn/oss/2.0']," +
                        "'course':['https://api.advanpro.cn/course/1.0']," +
                        "'dev':['https://api.advanpro.cn/api/devuc/1.0']," +
                        "'msg':['https://api.advanpro.cn/api/msg/2.0']" +
                        "}";
                break;
        }
        return JSON.parseObject(urlJsonString, new TypeReference<Map<String, List<String>>>() {
        });
    }

    public void setToken(Token token) {
        this.token = token;
    }

    /**
     * 获取默认的 CloudService
     * 需要先初始化 createDefault，否则会返回null
     *
     * @return CloudService
     */
    public static CloudService getDefault() {
        return defaultInstance;
    }

    /**
     * 创建默认的 CloudService
     *
     * @return
     */
    public static CloudService createDefault() {
        final CloudService cloudService = create();
        CloudService.defaultInstance = cloudService;
        return cloudService;
    }

    /**
     * 创建默认的 CloudService
     *
     * @param token
     * @return
     */
    public static CloudService createDefault(Token token) {
        final CloudService cloudService = create(token);
        CloudService.defaultInstance = cloudService;
        return cloudService;
    }

    /**
     * 创建CloudService
     *
     * @param token
     * @return
     */
    public static CloudService create(Token token) {
        return new CloudService(token);
    }

    /**
     * 创建CloudService
     *
     * @return
     */
    public static CloudService create() {
        return new CloudService();
    }

    public CloudService(Token token) {
        this();
        this.token = token;
    }

    public CloudService() {
        // 创建API
        initApi(apiAddressMap);
        initInterceptor();
    }

    private void initInterceptor() {
        for (CloudApi a : APIS.values()) {
            // 设置token
            a.addHeader(HEAD_OPTION_AUTHORIZATION, requestInterceptor);
            // 设置user_agent
            a.addHeader(HEAD_OPTION_USER_AGENT, requestInterceptor);
            // 设置语言
            a.addHeader(HEAD_OPTION_X_ACCEPT_LANGUAGE, requestInterceptor);
            // 设置响应过滤器
            a.addResponseInterceptor(responseInterceptor);
        }
    }

    public UCApi getUcApi() {
        return getApi(UCApi.class);
    }

    public DDCApi getDdcApi() {
        return getApi(DDCApi.class);
    }

    public SACApi getSacApi() {
        return getApi(SACApi.class);
    }

    public OSSApi getOssApi() {
        return getApi(OSSApi.class);
    }

    public AdminApi getAdminApi() {
        return getApi(AdminApi.class);
    }

    public CMSApi getCmsApi() {
        return getApi(CMSApi.class);
    }

    public OCApi getOcApi() {
        return getApi(OCApi.class);
    }

    public SOCApi getSocApi() {
        return getApi(SOCApi.class);
    }

    public QCApi getQcApi() {
        return getApi(QCApi.class);
    }

    public CDNApi getCDNApi() {
        return getApi(CDNApi.class);
    }

    public CourseApi getCourseApi() {
        return getApi(CourseApi.class);
    }

    public DevUCApi getDevUCApi() {
        return getApi(DevUCApi.class);
    }

    public MsgApi getMsgApi() {
        return getApi(MsgApi.class);
    }


    public <T extends CloudApi> T getApi(Class<T> clazz) {
        CloudApi cloudApi = APIS.get(clazz);
        if (cloudApi != null) {
            return (T) cloudApi;
        }
        return null;
    }

    public <T extends CloudApi> void addApi(Class<T> clazz, CloudApi cloudApi) {
        APIS.put(clazz, cloudApi);
    }

    public void addResponseInterceptor(ResponseFailureCallback interceptor) {
        this.failureInterceptor = interceptor;
        for (CloudApi a : APIS.values()) {
            a.addResponseInterceptor(failureInterceptor);
        }
    }

    public void addResponseInterceptor(ResponseErrorCallback interceptor) {
        this.errorInterceptor = interceptor;
        for (CloudApi a : APIS.values()) {
            a.addResponseInterceptor(errorInterceptor);
        }
    }

    protected void initApi(Map<String, List<String>> apiUrlMap) {
        for (Map.Entry<String, List<String>> entry : apiUrlMap.entrySet()) {
            // apiName
            String aName = entry.getKey();
            // 从 API_CLASS_MAP 获取对应的ApiClass
            Class<? extends CloudApi> aClass = API_CLASS_MAP.get(aName);
            if (aClass != null) {
                CloudApiManager.register(aClass, apiUrlMap.get(aName).toArray(new String[apiUrlMap.get(aName).size()]));
                APIS.put(aClass, CloudApiManager.create(aClass));
            }
        }
    }

    //请求连接器
    public RequestInterceptor requestInterceptor = new RequestInterceptor() {
        @Override
        public void invoke(int type, Request.Builder builder, ParameterOptions options, Object args) {
            if (RequestInterceptor.HEADER == type) {
                String optionName = options.getName();
                switch (optionName) {
                    case HEAD_OPTION_USER_AGENT:
                        //设置X-User-Agent
                        if (userAgent != null) {
                            builder.addHeader(optionName, userAgent.getUserAgent());
                        }
                        break;
                    case HEAD_OPTION_X_ACCEPT_LANGUAGE:
                        // 设置语言 X-Accept-Language
                        if (StringUtils.isNotEmpty(acceptLanguage)) {
                            builder.addHeader(optionName, acceptLanguage);
                        }
                        break;
                    case HEAD_OPTION_AUTHORIZATION:
                        //设置token
                        if (StringUtils.isNotEmpty(token.getToken())) {
                            builder.addHeader(optionName, token.getToken());
                        }
                        break;
                }
            }
        }
    };

    //响应连接器
    private ResponseInterceptor responseInterceptor = new ResponseInterceptor() {
        @Override
        public void invoke(Call call, Response response, Throwable throwable) {
            if (response != null && StringUtils.isNotEmpty(response.header(HEAD_OPTION_AUTHORIZATION))) {
                //设置得到token,交给回调处理
                token.setToken(response.header(HEAD_OPTION_AUTHORIZATION).toString());
            }
        }
    };

    protected void setAddressType(CloudAddressType addressType) {
        this.addressType = addressType;
    }

    public static CloudAddressType getAddressType() {
        return addressType;
    }

    /**
     * 拼接取得图片地址
     *
     * @param picture 云端返回的图片地址
     * @return https 地址，如果找不到返回""
     */
    public static final String getPicturePath(String picture) {
        return getCdnResourcePath(picture);
    }

    /**
     * 取得cdn url 路径
     *
     * @param url
     * @return
     */
    public static final String getCdnResourcePath(String url) {
        if (StringUtils.isEmpty(url)) {
            return "";
        }
        if (url.startsWith("https://") || url.startsWith("http://")) {
            // 已经带有网络绝对路径，不需要处理
            return url;
        }
        String[] urls = CloudApiManager.getUrls(CDNApi.class);
        if (urls != null && urls.length > 0) {
            return urls[0] + (url.startsWith("/") ? "" : "/") + url;
        }
        return "";
    }

//    public static final String getResourcePath(String url,Class myClass) {
//        if (StringUtils.isEmpty(url)) {
//
//            return "";
//        }
//        if (url.startsWith("https://") || url.startsWith("http://")) {
//            // 已经带有网络绝对路径，不需要处理
//            return url;
//        }
//        String[] urls = CloudApiManager.getUrls(myClass);
//        if (urls != null && urls.length > 0) {
//            return urls[0] + (url.startsWith("/") ? "" : "/") + url;
//        }
//        return "";
//    }


    /**
     * 拼接取得资源内容地址
     *
     * @param id 资源内容详情ID
     * @return https 地址，如果找不到返回""
     */
    public static final String getResourcesDetailPath(String id) {
        String path = String.format("/app/wikipedia/resources/%s.html", id);

        String[] urls = CloudApiManager.getUrls(CMSApi.class);
        if (urls != null && urls.length > 0) {
            return urls[0] + path;
        }
        return "";
    }

    /**
     * 获取商城地址
     *
     * @return https 地址，如果找不到返回""
     */
    public static final String getShopHomeUrl() {
        String[] urls = CloudApiManager.getUrls(SHOPApi.class);
        if (urls != null && urls.length > 0) {
            return urls[0];
        }
        return "";
    }

    /**
     * 获取商城地址
     *
     * @return https 地址，如果找不到返回""
     */
    public static final String getHomeUrl() {
        String[] urls = CloudApiManager.getUrls(HomeApi.class);
        if (urls != null && urls.length > 0) {
            return urls[0];
        }
        return "";
    }

    /**
     * 获取太极跑报名二维码地址
     *
     * @param coachId
     * @param courseId
     * @return
     */
    public static final String getEnrollUrl(String coachId, String courseId) {
        String path = String.format("/coach/%s/course/%s", coachId, courseId);

        String[] urls = CloudApiManager.getUrls(WebApi.class);
        if (urls != null && urls.length > 0) {
            return urls[0] + path;
        }
        return "";
    }

    /**
     * 获取太极跑签到二维码地址
     *
     * @param courseId
     * @return
     */
    public static final String getSignUrl(String courseId) {
        String path = String.format("/mycourse/sign/checking?courseId=%s", courseId);

        String[] urls = CloudApiManager.getUrls(WebApi.class);
        if (urls != null && urls.length > 0) {
            return urls[0] + path;
        }
        return "";
    }

}
