package hk.advanpro.cloud.android.common;

import android.content.Context;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageManager;

import java.util.HashMap;
import java.util.Map;

import hk.advanpro.cloud.android.model.CloudAddressType;

/**
 * 获取云端模式
 * 开发：DEV,
 * 测试版本：UAT ,
 * 预上线：PerPro,
 * 正式版本：PRODUCT
 * <p>
 * 第一步：在 AndroidManifest.xml 添加
 * <meta-data android:name="ROUTER_ADDRESS" android:value="XXXX" />
 * 例如，DEV
 * <meta-data android:name="ROUTER_ADDRESS" android:value="DEV" />
 * <p>
 * 第二步，获取
 * RouterAddressUtils.RouterAddressType roterAddressType = RouterAddressUtils.getRoterAddressType(this);
 * Created by jalin on 2018/1/6.
 */
public class RouterAddressUtils {
    public static final String META_DATE_KEY = "ROUTER_ADDRESS";

    public enum RouterAddressType {
        DEV("DEV"), UAT("UAT"), PerPro("PerPro"), PRODUCT("PRODUCT");
        String text;

        RouterAddressType(String text) {
            this.text = text;
        }

        public String getText() {
            return text;
        }
    }

    public final static Map<RouterAddressType, CloudAddressType> addressTypeMap = new HashMap<RouterAddressType, CloudAddressType>() {{
        put(RouterAddressType.UAT, CloudAddressType.UAT);
        put(RouterAddressType.DEV, CloudAddressType.DEV);
        put(RouterAddressType.PerPro, CloudAddressType.PRODUCT);
        put(RouterAddressType.PRODUCT, CloudAddressType.PRODUCT);
    }};
    /**
     * @param context
     * @return
     * @throws PackageManager.NameNotFoundException
     */
    public static RouterAddressType getRoterAddressType(Context context) throws PackageManager.NameNotFoundException {
        RouterAddressType routerAddressType;
        ApplicationInfo info = context.getPackageManager().getApplicationInfo(context.getPackageName(), PackageManager.GET_META_DATA);
        String routerAddress = info.metaData.getString(META_DATE_KEY);
        if (routerAddress.equals(RouterAddressType.DEV.getText())) {
            routerAddressType = RouterAddressType.DEV;
        } else if (routerAddress.equals(RouterAddressType.UAT.getText())) {
            routerAddressType = RouterAddressType.UAT;
        } else if (routerAddress.equals(RouterAddressType.PerPro.getText())) {
            routerAddressType = RouterAddressType.PerPro;
        } else {
            routerAddressType = RouterAddressType.PRODUCT;
        }
        return routerAddressType;
    }

    public static CloudAddressType getCloudAddressType(RouterAddressType routerAddressType){
        return addressTypeMap.get(routerAddressType);
    }
}
