package hk.advanpro.cloud.android.common;

import android.content.Context;

import org.apache.commons.lang3.StringUtils;

import java.security.PublicKey;
import java.util.HashMap;
import java.util.Map;

import hk.advanpro.android.core.utils.Base64Utils;
import hk.advanpro.android.core.utils.RSAUtils;
import hk.advanpro.android.core.utils.SystemUtils;

/**
 * 公钥文件
 */
public class SecurityUtils {

    /**
     * 公钥文件
     */
    private static final Map<String, String> publicKeyFileMap = new HashMap<String, String>() {{
        put("hk.advanpro.laf", "MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnTbyxhFviVSOkYJu8WGl\rEBaSexZEpjTZEurdgxL5hjUCj5sxNjZ6Jz6B8Qps+swBgqudjl/nroJvhlCJHwkF\rn+EQqIMHKxF7m7Luzd5IhydXdJfzkZ5lfDiUVRiT/duWtix49Wjxx0H3rosZc2TG\rj0kv89oOttOx89/u4SC6nNKWp0/3RDpoZhA8N/QqmWT0SrtdCT9jjAKymaYjJiq9\r3LeN6M7HZnGweqYvc7em+K/sYtN1vxC4pKhKixhQJ4yRAGKLl3qrJ1k49EGJzbN7\rafI89+xGlcfB6omzBFbiBxgjxr0HeqGP5Z8serVTG7zTIxHc6r2L8Fe4sIbKHR+3\ruwIDAQAB\r");
        put("hk.advanpro.lamaze", "MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqUbOOmT4N/JYwmCaYa/+\rct3EWVirJGK1Lq0JSQsw+SOXgYpns8XyQ6pUjfkdtaD9AtfYc2EscT6q6jf0Ouaf\rMMZPrTBJcMYED09fIolwfYJUqj4OW+uIXzM9rX7N+w5h3xfIIgIyeP6GhsR5jWv/\r+TXC9/JvMgPDtWCPd2JEhGpE535aSjCGpxEobWTP2Gw5kHLctEL8+cYqStp91djq\rPhERJzQ8hkEERSvdJgiMaLErwfr7jYDbZz2Yua5AIG9D3YD/U0BnhCLbiGb5mHZx\rhoOMnMp69VkDAFppDtqDePW+MZnDf3MlgzspQfAfvUJfsga4HYYzhncMCLvKHYya\rpQIDAQAB\r");
        put("hk.advanpro.qc", "MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA20R6wmXkuMGs/wUc5e6R\rjwkMoqEFSQb8JgwpJtJArfp9SFwV3MIKKA0CidqsPuIbPg61SHM/Ner9rBkKMPwj\rc8zIkajKfU+D/XkHjdjKxyhLht0jE4A2Na7Xhe4VqY1lbcCsfCEERbzWl4BJWsgr\r8a2LSQp+Sso1e5UBGi2IGSOMzSqbYJmt71A2nu/ZYeVbP7elTeZvTIQPDOlWTFGM\r3BXqVkqFwj8u+3vS/c+o2jQmnPi+lxVZdj6H2ByJTnUvOOwwCXP0OrfzgJmhSMUC\rEf1xkjUemka3b1k5QiUmaE7iIwYvghFpwmuDxh6kNUBOl/jYGcfDXsXutXg5eqTP\rAQIDAQAB\r");
        put("hk.advanpro.hub", "MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoaBZyl1txeHzzX8ukQ/v\rUon3wx91vLMbauS26bMLyppdAL0SuyCgkOOwaw3c7lc0PU8Xo+JsAKoGnvjp1m4t\rtDmWYW6hEN/NKNumWb3QXgfJCKqyoRy1tcY0dD30fbZqCN7l4BfP91/+pDcwNmPj\r5buqFokeTwk1ys1DqgMY1VQ4v/61YR4Ii2/TNyt++P4jp1Z8FuRTdB5k+0/dJv6+\rQhZegDE+YBsZmKF8sfPYRpaQWLHDyASU4vLNf2ctJAV9zLWH3hwjPbQsqf0fV+wm\rthKxBss38AcKnSsLtCDD6CSBIExVAy5izvZg0tSZ5TgjBgCiXUkIe+Mti8c+DbSx\rEQIDAQAB\r");
        put("hk.advanpro.chirunning", "MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0ipsoPHFML4nDzQLzRA+\rTDy4b4oRB0+Ws0xRBdcWWVBC4VKx9ewsXr+K9C9TyjPNf324RYGJEaXZmgYuUR5Q\rWAKjmkVTxWzX0+jjsiscq8g9PK4KuSm1PS2EOFw3aAb5yRVebgXNQ0F8SNl69Fcm\r4TjmrdPTW+fciRcJCep2+Dvp2B/dCUMxR3hm+faz65a3dsjl6OFgewd4UrciNQAp\rQQ1VutbBuidDnoEV736bZ9uhodSwoCZFlvzkHxKBf+FtEGf7CAtSbZPkA5UIiYeM\rka+MXKFLBm/N3pFiNPF/JbuFuQKwsoP83Fw0xaPOQwRrh5512uuEFHxhXyS7sWhy\rHQIDAQAB\r");
        put("hk.advanpro.chicoach", "MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzhEhP+uWiKzyGg1/UTKl\rsRUGyt2mc0czNF6AOVJrOIDxJyxBfbEPCCi42JqVYv/1z9YUOtIIcqC39406NnYW\rJqh44AZR/EZDsFt1r+X/TlkfpD+MnfjCvq1Qo0o1CCMbLEQ/ge1D/kk3a1EYZQ0k\rvU8mTsG0H/eY+6hAlL3IFJRQrUcL2x0/OHaI3ClG/S558ZJpfkSA0RddZ7hUoGE4\r83qmxSSYjFJI8aQg5UeDy02OuQIeqLNVPESXPeZtzqbiWyZ63s6GRNK3XLywKoh7\rwxiU62NqBk+58kbGNeZuJWTALkLF6Raw3T7VzVnwyUNnxSG2DVNQGm1x2PLa4LWY\rPwIDAQAB\r");
    }};

    /**
     * 加密算法
     *
     * @param context 包名
     * @param text    需要加密的字符串
     * @return 返回加密后的字符串
     * @throws Exception
     */
    public static String encrypt(Context context, String text) throws Exception {
        String packageName = SystemUtils.getApkPackInfo(context).packageName;
        String publicKeyValue = publicKeyFileMap.get(packageName);
        if (StringUtils.isNotEmpty(publicKeyValue)) {
            PublicKey publicKey = RSAUtils.loadPublicKey(publicKeyValue);
            // 加密
            byte[] encryptByte = RSAUtils.encryptData(text.getBytes(), publicKey);
            return Base64Utils.encode(encryptByte);
        }
        return text;
    }

}
