package hk.advanpro.cloud.android.common;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import hk.advanpro.cloud.android.model.CloudAddressType;
import hk.advanpro.cloud.api.CloudApiManager;
import hk.advanpro.cloud.api.client.CDNApi;
import hk.advanpro.cloud.api.result.RestfulResult;

/**
 * 服务器地址管理工具
 *
 * @author jalin
 * created at 2018/7/5
 */
public class ServiceUrlUtils {

    public static final String PRODUCT_API_SERVICE_URL = "https://cdn.advanpro.cn/servers/release";
    public static final String UAT_API_SERVICE_URL = "https://cdn.advanpro.cn/servers/test";
    public static final String DEV_API_SERVICE_URL = "https://cdn.advanpro.cn/servers/develop";

    /**
     * 从云端获取API的URl
     * 耗时方法，请不要在UI线程调用
     *
     * @param cloudAddressType 云端环境，枚举 CloudAddressType
     * @param appCode          App名称，如拉风智能裤：laf
     * @param serviceNames     服务器名称
     * @return
     * @throws Exception
     */
    public static Map<String, List<String>> getAdvanproServiceUrls(CloudAddressType cloudAddressType, String appCode, List<String> serviceNames) throws Exception {
        String apiServersUrl;

        // 先初始化cdn
        switch (cloudAddressType) {
            case DEV:
                apiServersUrl = DEV_API_SERVICE_URL;
                break;
            case UAT:
                apiServersUrl = UAT_API_SERVICE_URL;
                break;
            case PRODUCT:
            default:
                apiServersUrl = PRODUCT_API_SERVICE_URL;
                break;
        }

        return getAdvanproServiceUrls(apiServersUrl, appCode, serviceNames);
    }

    /**
     * 从云端获取API的URl
     * 耗时方法，请不要在UI线程调用
     *
     * @param apiServersUrl 管理url的服务器地址
     * @param appCode       App名称，如拉风智能裤：laf
     * @param serviceNames  服务器名称
     * @return
     * @throws Exception
     */
    public static Map<String, List<String>> getAdvanproServiceUrls(String apiServersUrl, String appCode, List<String> serviceNames) throws Exception {
        // 先初始化cdn
        CloudApiManager.register(CDNApi.class, apiServersUrl);
        CDNApi cdnApi = CloudApiManager.create(CDNApi.class);

        Map<String, List<String>> urlMap = new HashMap<>();
        for (String apiName : serviceNames) {
            RestfulResult<List<String>> restfulResult = cdnApi.getUrls(appCode, apiName).await();
            if (restfulResult.getCode() != 200) {
                throw new Exception(apiName + " service is not find and code = " + restfulResult.getCode() + ".");
            }
            urlMap.put(apiName, restfulResult.getData());
        }
        return urlMap;
    }
}
