package hk.advanpro.cloud.api;

import java.lang.reflect.Proxy;
import java.util.HashMap;
import java.util.Map;

import hk.advanpro.cloud.api.callback.ResponseErrorCallback;
import hk.advanpro.cloud.api.callback.ResponseFailureCallback;
import hk.advanpro.cloud.api.client.CloudApi;
import hk.advanpro.cloud.api.interceptor.RequestInterceptor;
import hk.advanpro.cloud.api.interceptor.ResponseInterceptor;
import hk.advanpro.cloud.api.options.ParameterOptions;
import hk.advanpro.cloud.api.options.RequestOptions;

/**
 * 云端接口管理器，用于配置全局参数及实例化具体接口实例对象。
 * Created by yejianfei on 2017/8/12.
 */

public class CloudApiManager {

    private static RequestOptions options = new RequestOptions();

    private static Map<Class<? extends CloudApi>, String[]> URLS = new HashMap<>();

    public static void register(Class<? extends CloudApi> clazz, String... url) {
        URLS.put(clazz, url);
    }

    public static void addHeader(String name, String value) {
        options.getParameters().add(new ParameterOptions(0, ParameterOptions.HEADER, name, value, ParameterOptions.TYPE));
    }

    public static void addHeader(String name, RequestInterceptor interceptor) {
        options.getParameters().add(new ParameterOptions(0, ParameterOptions.HEADER, name, null, interceptor, ParameterOptions.TYPE));
    }

    public static void addResponseInterceptor(ResponseInterceptor interceptor) {
        addResponseInterceptor(interceptor, null, null);
    }

    public static void addResponseInterceptor(ResponseFailureCallback failureCallback) {
        addResponseInterceptor(null, failureCallback, null);
    }

    public static void addResponseInterceptor(ResponseErrorCallback errorCallback) {
        addResponseInterceptor(null, null, errorCallback);
    }

    public static void addResponseInterceptor(ResponseInterceptor interceptor, ResponseFailureCallback failureCallback, ResponseErrorCallback errorCallback) {

        options.getParameters().add(new ParameterOptions(
                ParameterOptions.RESPONSE,
                interceptor,
                failureCallback,
                errorCallback,
                ParameterOptions.TYPE));
    }

    @SuppressWarnings("unchecked")
    public static <T extends CloudApi> T create(Class<T> clazz) {
        CloudApiProxy api = new CloudApiProxy(clazz, URLS.get(clazz), options);
        return (T) Proxy.newProxyInstance(CloudApiManager.class.getClassLoader(), new Class[]{clazz}, api);
    }

    public static CloudApi create(String baseUrl) {
        CloudApiProxy api = new CloudApiProxy(baseUrl, options);
        return (CloudApi) Proxy.newProxyInstance(CloudApiManager.class.getClassLoader(), new Class[]{CloudApi.class}, api);
    }

    public static final <T extends CloudApi> String[] getUrls(Class<T> clazz) {
        return URLS.get(clazz);
    }
}
