package hk.advanpro.cloud.api.client;

import hk.advanpro.cloud.api.CloudRequestContext;
import hk.advanpro.cloud.api.annotation.Header;
import hk.advanpro.cloud.api.annotation.Headers;
import hk.advanpro.cloud.api.annotation.JsonPayload;
import hk.advanpro.cloud.api.annotation.PathVariable;
import hk.advanpro.cloud.api.annotation.RequestMethod;
import hk.advanpro.cloud.api.annotation.Url;
import hk.advanpro.cloud.api.payload.MyFeedbackPayload;
import hk.advanpro.cloud.api.result.RestfulResult;
import hk.advanpro.cloud.api.result.oss.ProdectVersionResult;
import hk.advanpro.cloud.api.result.uc.LoginResult;

/**
 * 管理中心云端接口
 * Created by jalin on 2017/11/24.
 */

@Headers({
        @Header(name = "Content-Type", value = "application/json")
})
public interface AdminApi extends CloudApi {
    public static final String NAME = "admin";
    /**
     * 员工登录请求接口。
     *
     * @param account 登录账号
     * @param passwd  登录密码
     * @return 请求上下文环境
     */
    @Url(value = "/login", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<LoginResult>> login(
            @JsonPayload("account") String account,
            @JsonPayload("passwd") String passwd);


    /**
     * 获取最新的应用、固件等版本信息
     *
     * @param category 类别 APP/FIRMWARE/OTHER
     * @param platform 平台 ANDROID/IOS/EMBED
     * @param product  产品名称
     * @return 应用信息
     */
    @Url(value = "/apps/{category}/{platform}/{product}/latest", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<ProdectVersionResult>> getVersion(@PathVariable("category") String category,
                                                  @PathVariable("platform") String platform,
                                                  @PathVariable("product") String product);

    /**
     * 获取最新的应用版本信息
     *
     * @param product 产品名称 如：UNIFIT
     * @return 应用信息
     */
    @Url(value = "/apps/APP/ANDROID/{product}/latest", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<ProdectVersionResult>> getAndroidAppVersion(@PathVariable("product") String product);

    /**
     * 获取最新的固件信息
     *
     * @param product 产品名称 如：SISB1.3（智能鞋垫）
     * @return 应用信息
     */
    @Url(value = "/apps/FIRMWARE/EMBED/{product}/latest", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<ProdectVersionResult>> getFirmwareVersion(@PathVariable("product") String product);


    /**
     * 添加用户反馈的请求接口
     *
     * @param payload
     * @return 请求上下文
     */
    @Url(value = "/my/feedbacks", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> addMyFeedbacks(@JsonPayload() MyFeedbackPayload payload);
}
