package hk.advanpro.cloud.api.client;

import java.util.List;

import hk.advanpro.cloud.api.CloudRequestContext;
import hk.advanpro.cloud.api.annotation.Header;
import hk.advanpro.cloud.api.annotation.Headers;
import hk.advanpro.cloud.api.annotation.PathVariable;
import hk.advanpro.cloud.api.annotation.RequestMethod;
import hk.advanpro.cloud.api.annotation.Url;
import hk.advanpro.cloud.api.result.RestfulResult;
import hk.advanpro.cloud.api.result.oss.ProdectVersionResult;

/**
 * CDN
 * @author jalin
 * created at 2018/7/5
 */
@Headers({
        @Header(name = "Content-Type", value = "application/json")
})
public interface CDNApi extends CloudApi {
    public static final String NAME = "cdn";

    @Url(value = "/{appCode}/{api}.json", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<String>>> getUrls(@PathVariable("appCode") String appCode, @PathVariable("api") String api);


    /**
     * 获取最新APP版本信息
     *
     * @param product APP类型 ，如好好呼吸APP:laf
     * @return
     */
    @Url(value = "/apps/{product}/android/latest.json", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<ProdectVersionResult>> getAppVersionInfo(@PathVariable("product") String product);


    /**
     * 获取最新固件版本信息
     *
     * @param product 设备类型 如:好好呼吸：LF1.1（去前两位）
     * @return
     */
    @Url(value = "/firmwares/{product}/latest.json", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<ProdectVersionResult>> getFirmwareVersionInfo(@PathVariable("product") String product);



    /**
     * 推荐课程
     *
     * @param product APP类型 ，如好好呼吸APP:laf
     * @return
     */
    @Url(value = "wikipedia/text/{product}/recommend_course.json", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<String>> wikipedia(@PathVariable("product") String product);


    /**
     * 推荐课程
     *
     * @param product APP类型 ，如好好呼吸APP:laf
     * @return
     */
    @Url(value = "wikipedia/text/{product}/{json}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<String>> wikipedia2(@PathVariable("product") String product,@PathVariable("json") String json);
}
