package hk.advanpro.cloud.api.client;

import java.util.List;

import hk.advanpro.cloud.api.CloudRequestContext;
import hk.advanpro.cloud.api.annotation.Header;
import hk.advanpro.cloud.api.annotation.Headers;
import hk.advanpro.cloud.api.annotation.PathVariable;
import hk.advanpro.cloud.api.annotation.RequestMethod;
import hk.advanpro.cloud.api.annotation.RequestParam;
import hk.advanpro.cloud.api.annotation.Url;
import hk.advanpro.cloud.api.result.RestfulResult;
import hk.advanpro.cloud.api.result.cms.BaikeCategoryResult;
import hk.advanpro.cloud.api.result.cms.BaikeResourcesListResult;
import hk.advanpro.cloud.api.result.cms.BaikeResourcesResult;
import hk.advanpro.cloud.api.result.cms.MusicAlbumListResult;
import hk.advanpro.cloud.api.result.cms.MusicAlbumResult;
import hk.advanpro.cloud.api.result.cms.MusicCategoryResult;
import hk.advanpro.cloud.api.result.cms.MusicSongDetailResult;
import hk.advanpro.cloud.api.result.cms.MusicSongListResult;
import hk.advanpro.cloud.api.result.cms.MyMusicListResult;

/**
 * CMS 百科接口
 * Created by jalin on 201/06/12.
 */

@Headers({
        @Header(name = "Content-Type", value = "application/json")
})
public interface CMSApi extends CloudApi {
    public static final String NAME = "cms";

    /**
     * 获取分类
     *
     * @return
     */
    @Url(value = "/app/wikipedia/categorys", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<BaikeCategoryResult>>> getBaikeCategorys();


    /**
     * 获取推荐的内容
     *
     * @return
     */
    @Url(value = "/app/wikipedia/resources/recommend", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<BaikeResourcesResult>>> getBaikeResourcesRecommend();

    /**
     * 根据分类查找内容列表
     *
     * @param id   分类ID
     * @param page 页面
     * @param size 大小
     * @return
     */
    @Url(value = "/app/wikipedia/categorys/{id}/resources/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<BaikeResourcesListResult>> getBaikeResources(
            @PathVariable("id") String id,
            @PathVariable("page") int page,
            @RequestParam("size") int size
    );


    /**
     * 搜索
     *
     * @param keyword 搜索关键词
     * @param page    页码
     * @param size    大小
     * @return
     */
    @Url(value = "/app/wikipedia/search", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<BaikeResourcesListResult>> baikeSearch(
            @RequestParam("keyword") String keyword,
            @RequestParam("page") int page,
            @RequestParam("size") int size
    );

    /**
     * 根据标签获取内容列表
     *
     * @param code
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/app/wikipedia/resources/tags/{code}/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<BaikeResourcesResult>>> getBaikeResourcesByTags(
            @PathVariable("code") String code,
            @PathVariable("page") int page,
            @RequestParam("size") int size
    );


    // ---------------  音乐 --------------------


    /**
     * 获取栏目
     * 音乐分类
     *
     * @return
     */
    @Url(value = "/app/music/categorys", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<MusicCategoryResult>>> getMusicCategorys();


    /**
     * 根据栏目获取专辑列表
     *
     * @param p_id 栏目ID
     * @param page 页码
     * @param size 大小
     * @return
     */
    @Url(value = "/app/music/categorys/{p_id}/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<MusicAlbumListResult>> getMusicAlbumList(
            @PathVariable("p_id") String p_id,
            @PathVariable("page") int page,
            @RequestParam("size") int size
    );

    /**
     * 根据栏目获取专辑列表
     *
     * @param p_id    栏目ID
     * @param page    页码
     * @param size    大小
     * @param keyword 专辑名称
     * @return
     */

    @Url(value = "/app/music/categorys/{p_id}/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<MusicAlbumListResult>> getMusicAlbumList(
            @PathVariable("p_id") String p_id,
            @PathVariable("page") int page,
            @RequestParam("size") int size,
            @RequestParam("keyword") String keyword
    );

    /**
     * 专辑详情
     *
     * @return
     */
    @Url(value = "/app/music/categorys/{id}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<MusicAlbumResult>> getMusicAlbumDetail(@PathVariable("id") String id);

    /**
     * /**
     * 曲目列表-播放列表
     *
     * @param id
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/app/music/categorys/{id}/resources/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<MusicSongListResult>> getMusicResourceList(
            @PathVariable("id") String id,
            @PathVariable("page") int page,
            @RequestParam("size") int size
    );

    /**
     * 曲目列表-歌曲简介
     *
     * @param id 曲目ID
     * @return
     */
    @Url(value = "/app/music/resources/{id}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<MusicSongDetailResult>> getMusicResourceDetail(@PathVariable("id") String id);

    /**
     * 歌曲播放-播放音乐 收听次数
     *
     * @param music_id 专辑ID
     * @return
     */
    @Url(value = "/my/music/{music_id}", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> addMusicAudiences(@PathVariable("music_id") String music_id);

    /**
     * 我的歌单
     *
     * @param page 页码
     * @param size 大小
     * @return
     */
    @Url(value = "/my/music/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<MyMusicListResult>> getMyMusicList(
            @PathVariable("page") int page,
            @RequestParam("size") int size
    );
}
