package hk.advanpro.cloud.api.client;

import com.alibaba.fastjson.JSONObject;

import java.util.Date;
import java.util.List;

import hk.advanpro.cloud.api.CloudRequestContext;
import hk.advanpro.cloud.api.annotation.Header;
import hk.advanpro.cloud.api.annotation.Headers;
import hk.advanpro.cloud.api.annotation.JsonPayload;
import hk.advanpro.cloud.api.annotation.PathVariable;
import hk.advanpro.cloud.api.annotation.RequestMethod;
import hk.advanpro.cloud.api.annotation.RequestParam;
import hk.advanpro.cloud.api.annotation.Url;
import hk.advanpro.cloud.api.payload.course.AddTrainClassPayload;
import hk.advanpro.cloud.api.payload.course.CourseRecord;
import hk.advanpro.cloud.api.payload.course.CourseTrainUploadPayload;
import hk.advanpro.cloud.api.result.RestfulResult;
import hk.advanpro.cloud.api.result.course.CourseHistoryListResult;
import hk.advanpro.cloud.api.result.course.CourseListResult;
import hk.advanpro.cloud.api.result.course.CoursePrizesAllListResult;
import hk.advanpro.cloud.api.result.course.CoursePrizesListResult;
import hk.advanpro.cloud.api.result.course.CourseStatResult;
import hk.advanpro.cloud.api.result.course.CourseTrainDayResult;
import hk.advanpro.cloud.api.result.course.CourseTrainingResult;
import hk.advanpro.cloud.api.result.course.CourseTrainingsListResult;
import hk.advanpro.cloud.api.result.course.CourseWebkitsResult;
import hk.advanpro.cloud.api.result.course.TrainClassCommentListResult;
import hk.advanpro.cloud.api.result.course.TrainClassEnrollListResult;
import hk.advanpro.cloud.api.result.course.TrainClassEnrollResult;
import hk.advanpro.cloud.api.result.course.TrainClassItemResult;
import hk.advanpro.cloud.api.result.course.TrainClassListResult;
import hk.advanpro.cloud.api.result.course.TrainClassResult;

/**
 * Created by david on 2018/8/20.
 */

@Headers({
        @Header(name = "Content-Type", value = "application/json")
})
public interface CourseApi extends CloudApi {
    public static final String NAME = "course";

    /**
     * 获取课程列表
     *
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/courses/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<CourseListResult>> getCourseList(@PathVariable("page") int page,
                                                                       @RequestParam("size") int size);

    /**
     * 获取课程列表
     *
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/courses/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<JSONObject>> getCourseAllList(@PathVariable("page") int page,
                                                                    @RequestParam("size") int size);


    /**
     * 获取课程列表
     *
     * @param page
     * @param size
     * @param keyword
     * @return
     */
    @Url(value = "/courses/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<CourseListResult>> getCourseList(@PathVariable("page") int page,
                                                                       @RequestParam("size") int size,
                                                                       @RequestParam("keyword") String keyword);

    /**
     * 获取我是否学习过某一课程
     *
     * @param id 课程主键
     * @return
     */
    @Url(value = "/my/courses/{id}/exists", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<Boolean>> checkCourse(@PathVariable("id") String id);


    /**
     * 获取我是否学习过某一章节
     *
     * @param id 课程主键
     * @return
     */
    @Url(value = "/my/courses/{id}/chapters/{chapter_id}/exists", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<Boolean>> checkChapters(
            @PathVariable("id") String id,
            @PathVariable("chapter_id") String chapter_id
    );


    /**
     * 获取我的奖项记录
     *
     * @param id   课程主键
     * @param type - all:全部
     * @param page 页码
     * @param size 大小
     * @return
     */
    @Url(value = "/my/courses/{id}/prizes/{type}/items/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<CoursePrizesListResult>> getCoursesPrizes(@PathVariable("id") String id,
                                                                                @PathVariable("type") String type,
                                                                                @PathVariable("page") int page,
                                                                                @RequestParam("size") int size);


    /**
     * 获取课程下奖品统计
     *
     * @param id   课程Id
     * @param code 奖品编码
     * @return
     */
    @Url(value = "/courses/{id}/prizes/{code}/stat", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult> getCoursesPrizeOwnerCount(@PathVariable("id") String id,
                                                                 @PathVariable("code") String code);

    /**
     * 获取课程下奖项统计
     *
     * @param id   课程Id
     * @param code 奖项编码
     * @return
     */
    @Url(value = "/courses/{id}/prizes/{code}/stat", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult> getCoursesPrizeItemOwnerCount(@PathVariable("id") String id,
                                                                     @PathVariable("code") String code);

    /**
     * 获取课程详情
     *
     * @param id
     * @return
     */
    @Url(value = "/courses/{id}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult> getCoursesInfo(@PathVariable("id") String id);


    /**
     * 获取我的课程统计信息
     *
     * @param id 课程主键
     * @return
     */
    @Url(value = "/my/courses/{id}/stat", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<CourseStatResult>> getCoursesStat(@PathVariable("id") String id);

    /**
     * 获取我的课程统计信息
     *
     * @param id 课程主键
     * @return
     */
    @Url(value = "/my/courses/{id}/stat", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult> getMyCoursesStat(@PathVariable("id") String id);


    /**
     * 获取我的奖项记录项
     *
     * @param id   课程主键
     * @param type - all:全部
     *             - medal:勋章
     *             - title:称号
     *             - grade:等级
     * @param page 页码
     * @param size 大小
     */
    @Url(value = "/my/courses/{id}/prizes/{type}/items/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult> getMyCoursesPrizeItemList(@PathVariable("id") String id,
                                                                 @PathVariable("type") String type,
                                                                 @PathVariable("page") int page,
                                                                 @RequestParam("size") int size);

    /**
     * 获取我的课程训练记录
     *
     * @param id   课程主键
     * @param page 页码
     * @param size 大小
     * @return
     */
    @Url(value = "/my/courses/{id}/trainings/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<CourseTrainingsListResult>> getCoursesTraining(@PathVariable("id") String id,
                                                                                     @PathVariable("page") int page,
                                                                                     @RequestParam("size") int size);


    /**
     * 获取我的课时表
     *
     * @param id   课程主键
     * @param date 当天0点的格林时间
     * @return
     */
    @Url(value = "/my/courses/{id}/schedule", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult> getMyCourseSchedule(@PathVariable("id") String id,
                                                           @RequestParam("date") String date);

    /**
     * 上传我的训练数据
     * 拉风智能裤
     *
     * @param is_reset 是否重置
     * @param app_data app应用数据
     * @return
     */
    @Url(value = "/my/trainings", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<CourseTrainingResult>> setTraining(@JsonPayload("is_reset") boolean is_reset,
                                                                         @JsonPayload("app_data") CourseRecord app_data);

    /**
     * 上传我的训练数据
     *
     * @param is_reset 是否重置
     * @param app_data app应用数据
     * @return
     */
    @Url(value = "/my/trainings", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> uploadTraining(@JsonPayload("is_reset") boolean is_reset,
                                                      @JsonPayload("app_data") CourseTrainUploadPayload app_data);


    /**
     * 获取我的训练详情
     *
     * @param id
     * @return
     */
    @Url(value = "/my/trainings/{id}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<JSONObject>> getTrainingDetail(@PathVariable("id") String id);


    /**
     * 获取训练记录
     *
     * @param course
     * @param begin
     * @param end
     * @return
     */
    @Url(value = "/laf/course/{course}/list", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<CourseHistoryListResult>> getHistoryTraining(@PathVariable("course") String course,
                                                                                   @RequestParam("begin") String begin,
                                                                                   @RequestParam("end") String end);


    /**
     * 获取勋章
     *
     * @param course
     * @param type
     * @param page
     * @return
     */
    @Url(value = "/courses/{id}/prizes/{type}/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<CoursePrizesAllListResult>> getAllPrizes(@PathVariable("id") String course,
                                                                               @PathVariable("type") String type,
                                                                               @PathVariable("page") String page);

    /**
     * 获取课程下奖品列表
     *
     * @param id   课程主键
     * @param type - all:全部
     *             - medal:勋章
     *             - title:称号
     *             - grade:等级
     * @param page 页码
     * @param size 大小
     * @return
     */
    @Url(value = "/courses/{id}/prizes/{type}/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult> getCoursesPrizesList(@PathVariable("id") String id,
                                                            @PathVariable("type") String type,
                                                            @PathVariable("page") int page,
                                                            @RequestParam("size") int size);


    /**
     * 转发获得勋章
     *
     * @param id 训练id
     * @return
     */
    @Url(value = "/my/trainings/{id}/forward", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> share(@PathVariable("id") String id);

    /**
     * 获取我的课程训练日期
     * 默认时区+8:00
     *
     * @param id    课程主键
     * @param begin 开始时间 UTC 时区 DateUtils.formatDateToUTC(beginDate)
     * @param end   结束时间 UTC 时区 DateUtils.formatDateToUTC(endDate)
     * @param id
     * @param begin
     * @param end
     * @return
     */
    @Url(value = "/my/courses/{id}/trainings/days/list", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<CourseTrainDayResult>>> getMyTrainingDays(@PathVariable("id") String id,
                                                                                     @RequestParam("begin") String begin,
                                                                                     @RequestParam("end") String end);

    /**
     * 获取我的课程训练日期
     *
     * @param id       课程主键
     * @param begin    开始时间 UTC 时区 DateUtils.formatDateToUTC(beginDate)
     * @param end      结束时间 UTC 时区 DateUtils.formatDateToUTC(endDate)
     * @param timezone 时区
     * @return
     */
    @Url(value = "/my/courses/{id}/trainings/days/list", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<CourseTrainDayResult>>> getMyTrainingDays(@PathVariable("id") String id,
                                                                                     @RequestParam("begin") String begin,
                                                                                     @RequestParam("end") String end,
                                                                                     @RequestParam("timezone") String timezone);

    /**
     * 获取我的课程训练记录
     *
     * @param id      课程主键
     * @param page    页码
     * @param size    大小
     * @param chapter 章节主键
     * @param lesson  课时主键
     * @param begin   开始时间
     * @param end     结束时间
     * @return
     */
    @Url(value = "/my/courses/{id}/trainings/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult> getMyTrainingList(@PathVariable("id") String id,
                                                         @PathVariable("page") int page,
                                                         @RequestParam("size") int size,
                                                         @RequestParam("chapter") String chapter,
                                                         @RequestParam("lesson") String lesson,
                                                         @RequestParam("begin") Date begin,
                                                         @RequestParam("end") Date end);

    /**
     * 获取我的课程训练记录
     *
     * @param id    课程主键
     * @param page  页码
     * @param size  大小
     * @param begin 开始时间
     * @param end   结束时间
     * @return
     */
    @Url(value = "/my/courses/{id}/trainings/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult> getMyTrainingList(@PathVariable("id") String id,
                                                         @PathVariable("page") int page,
                                                         @RequestParam("size") int size,
                                                         @RequestParam("begin") Date begin,
                                                         @RequestParam("end") Date end);

    /**
     * 获取我的课程训练记录
     *
     * @param id   课程主键
     * @param page 页码
     * @param size 大小
     * @return
     */
    @Url(value = "/my/courses/{id}/trainings/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult> getMyTrainingList(@PathVariable("id") String id,
                                                         @PathVariable("page") int page,
                                                         @RequestParam("size") int size);

    /**
     * 获取课程最新课件
     *
     * @param id
     * @return
     */
    @Url(value = "/courses/{id}/webkits/latest", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<CourseWebkitsResult>> getCoursesWebkits(@PathVariable("id") String id);


    //--------- 太极跑教练 start ------------

    /**
     * 教练获取培训班课程分类
     *
     * @return
     */
    @Url(value = "/app/my/course/item", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<TrainClassItemResult>>> getTrainClassItemList();

    /**
     * 教练添加课程班
     *
     * @param trainClassPayload
     * @return
     */
    @Url(value = "/app/my/training/class", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> addTrainClass(@JsonPayload() AddTrainClassPayload trainClassPayload);

    /**
     * 教练修改课程班
     *
     * @param id
     * @param trainClassPayload
     * @return
     */
    @Url(value = "/app/my/training/class/{id}", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult> updateTrainClass(@PathVariable("id") String id,
                                                        @JsonPayload() AddTrainClassPayload trainClassPayload);

    /**
     * 修改培训班状态通道
     *
     * @param id
     * @param status
     * @param audit_reason
     * @return
     */
    @Url(value = "/aisle/class/{id}", method = RequestMethod.PUT)
    @Deprecated
    CloudRequestContext<RestfulResult> updateTrainClassStatus(@PathVariable("id") String id,
                                                              @RequestParam("status") int status,
                                                              @JsonPayload("audit_reason") String audit_reason);

    /**
     * 教练获取未上课的学生列表
     *
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/app/my/enroll/notsignin/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<TrainClassEnrollListResult>> getNotsiginStudentList(@PathVariable("page") int page,
                                                                                          @RequestParam("size") int size);


    /**
     * 教练取消培训班
     *
     * @param id
     * @return
     */
    @Url(value = "/app/my/training/class/{id}/disband", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult> cancelTrainClass(@PathVariable("id") String id);

    /**
     * 教练确认开培训班
     *
     * @param id
     * @return
     */
    @Url(value = "/app/my/training/class/{id}/begin", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> openTrainClass(@PathVariable("id") String id);

    /**
     * 教练完成培训班
     *
     * @param id
     * @return
     */
    @Url(value = "/app/my/training/class/{id}/finish", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> completeTrainClass(@PathVariable("id") String id);

    /**
     * 教练获取培训班列表(教练本人)
     *
     * @param page
     * @param size
     * @param status  状态
     *                - 2:申请中
     *                - 3:报名中
     *                - 4:待开课
     *                - 5:已完成
     * @param keyword 关键字
     * @return
     */
    @Url(value = "/app/my/training/class/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<TrainClassListResult>> getMyCoachTrainClassList(@PathVariable("page") int page,
                                                                                      @RequestParam("size") int size,
                                                                                      @RequestParam("status") int status,
                                                                                      @RequestParam("keyword") String keyword);

    /**
     * 培训班列表
     *
     * @param id
     * @param page
     * @param size
     * @param status
     * @param course
     * @param sort
     * @return
     */
    @Url(value = "/coach/{id}/training/class/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<TrainClassListResult>> getCoachTrainClassList(@PathVariable("id") String id,
                                                                                    @PathVariable("page") int page,
                                                                                    @RequestParam("size") int size,
                                                                                    @RequestParam("status") String status,
                                                                                    @RequestParam("course") String course,
                                                                                    @RequestParam("sort") int sort);

    /**
     * 教练获取培训班详情
     *
     * @param class_id
     * @return
     */
    @Url(value = "/app/my/training/class/{class_id}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<TrainClassResult>> getCoachTrainClassDetail(@PathVariable("class_id") String class_id);

    /**
     * 培训班报名列表
     *
     * @param page    页码
     * @param size    大小
     * @param shiftin 是否获取插班生(默认0)
     *                - 0:否
     *                - 1:是
     * @param status  状态  多个状态用逗号隔开
     *                - 0:已关闭
     *                - 1:待付款
     *                - 5:待开课
     *                - 10:待评价
     *                - 15:已评价
     *                - 20:已取消
     *                - 25:退款中
     *                - 30:已退款
     * @return
     */
    @Url(value = "/app/my/training/class/{id}/enroll/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<TrainClassEnrollListResult>> getCoachEnrollList(@PathVariable("id") String id,
                                                                                      @PathVariable("page") int page,
                                                                                      @RequestParam("size") int size,
                                                                                      @RequestParam("shiftin") int shiftin,
                                                                                      @RequestParam("status") String status);

    /**
     * 教练-详情-用户评价
     *
     * @param id
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/coach/{id}/comment/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<TrainClassCommentListResult>> getCoachCommentList(@PathVariable("id") String id,
                                                                                        @PathVariable("page") int page,
                                                                                        @RequestParam("size") int size);

    /**
     * 课程-获取评价
     *
     * @param id
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/training/class/{id}/comment/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<TrainClassCommentListResult>> getClassCommentList(@PathVariable("id") String id,
                                                                                        @PathVariable("page") int page,
                                                                                        @RequestParam("size") int size);

    /**
     * 报名详情
     *
     * @param id
     * @return
     */
    @Url(value = "/app/my/training/class/enroll/{id}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<TrainClassEnrollResult>> getCoachEnrollDetail(@PathVariable("id") String id);


    /**
     * 分会培训班列表
     *
     * @param page
     * @param size
     * @param status 状态
     *               - 2:申请中
     *               - 3:报名中
     *               - 5:待开课
     *               - 6:已完成
     * @param course 课程ID
     * @param sort   排序
     *               - 1:正序
     *               - -1:倒序
     * @return
     */
    @Url(value = "/app/my/branch/training/class/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<TrainClassListResult>> getBranchTrainClassList(@PathVariable("page") int page,
                                                                                     @RequestParam("size") int size,
                                                                                     @RequestParam("status") String status,
                                                                                     @RequestParam("course") String course,
                                                                                     @RequestParam("sort") int sort);

    /**
     * 更换教练（会长）
     *
     * @param coach_id     被更换教练Id
     * @param new_coach_id 教练id
     * @return
     */
    @Url(value = "/app/my/training/class/coach/change", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult> changeCoach(@JsonPayload("coach_id") String coach_id,
                                                   @JsonPayload("new_coach_id") String new_coach_id);

    /**
     * 修改培训班状态（通道）
     *
     * @param id
     * @param status
     * @param audit_reason
     * @return
     */
    @Url(value = "/aisle/class/{id}", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult> changeCourseStatus(@PathVariable("id") String id,
                                                          @RequestParam("status") int status,
                                                          @JsonPayload("audit_reason") String audit_reason);

    //--------- 太极跑教练 end ------------

}
