package hk.advanpro.cloud.api.client;

import java.util.List;

import hk.advanpro.cloud.api.CloudRequestContext;
import hk.advanpro.cloud.api.annotation.Header;
import hk.advanpro.cloud.api.annotation.Headers;
import hk.advanpro.cloud.api.annotation.JsonPayload;
import hk.advanpro.cloud.api.annotation.PathVariable;
import hk.advanpro.cloud.api.annotation.RequestMethod;
import hk.advanpro.cloud.api.annotation.RequestParam;
import hk.advanpro.cloud.api.annotation.Url;
import hk.advanpro.cloud.api.payload.ddc.AddAppDataPayload;
import hk.advanpro.cloud.api.payload.ddc.AddRawsFilePayload;
import hk.advanpro.cloud.api.payload.ddc.ReceiveInfoPayload;
import hk.advanpro.cloud.api.result.RestfulResult;
import hk.advanpro.cloud.api.result.ddc.AddAppDataResult;
import hk.advanpro.cloud.api.result.ddc.AppDataResult;
import hk.advanpro.cloud.api.result.ddc.CheckDeviceBindResult;
import hk.advanpro.cloud.api.result.ddc.DeviceInfoResult;
import hk.advanpro.cloud.api.result.ddc.MaintenanceListResult;
import hk.advanpro.cloud.api.result.ddc.MaintenanceResult;
import hk.advanpro.cloud.api.result.ddc.MyDeviceResult;
import hk.advanpro.cloud.api.result.ddc.MyOrderResult;

/**
 * Created by jalin on 2017/9/20.
 * <p>
 * jalin 2018/06/26 v2.0修改
 */

@Headers({
        @Header(name = "Content-Type", value = "application/json")
})
public interface DDCApi extends CloudApi {
    public static final String NAME = "ddc";


    @Url(value = "/my/devices", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<MyDeviceResult>>> getMyDevices();

    /**
     * 设备绑定
     *
     * @param codes 待绑定的设备id
     * @param force 是否强行绑定
     * @return 请求上下文环境
     */
    @Url(value = "/my/devices", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<List<MyDeviceResult>>> bindDevice(@JsonPayload("codes") String[] codes,
                                                                        @JsonPayload("force") boolean force);

    /**
     * 解除设备绑定
     *
     * @param codes 待解除的设备id
     * @return 请求上下文环境
     */
    @Url(value = "/my/devices", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult> unbindDevice(@JsonPayload("codes") String[] codes);
    /**
     * 检查设备能否被当前用户绑定,过滤设备列表
     *
     * @param old_devIds 原设备id
     * @param new_devIds 新设备ID
     * @return 请求上下文环境
     */
    @Url(value = "/my/devices/change/bind", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<List<MyDeviceResult>>> changeDeviceBind(@JsonPayload("old_codes") String[] old_devIds,
                                                                              @JsonPayload("new_codes") String[] new_devIds);

    /**
     * 检查设备能否被当前用户绑定,过滤设备列表
     *
     * @param devIds 待检查的设备,mac或id
     * @return 请求上下文环境
     */
    @Url(value = "/my/devices/filters", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<List<CheckDeviceBindResult>>> checkDeviceBind(@JsonPayload() String[] devIds);


    /**
     * 获取设备信息
     *
     * @param devId 设备ID
     * @return 请求上下文环境
     */
    @Url(value = "/my/devices/{devId}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<DeviceInfoResult>> getDeviceInfo(@PathVariable("devId") String devId);


    /**
     * 公开的，不需要登陆，检查设备能否被当前用户绑定,过滤设备列表
     *
     * @param devIds
     * @return
     */
    @Url(value = "/devices/filters", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<List<CheckDeviceBindResult>>> checkDeviceBindOpen(@JsonPayload() String[] devIds);


    /**
     * 公开的，不需要登陆
     * 通过设备校验码和设备类型获取设备信息
     *
     * @param vvcode     设备校验码
     * @param deviceType 产品类型
     *                   - 1:智能呼吸带
     *                   - 2:智能腰带
     *                   - 3:智能内裤
     *                   - 4:跑步智能鞋垫
     *                   - 7:跪垫
     *                   - 8:磕垫
     *                   - 10:开发板
     *                   - 11:开发鞋垫
     *                   - 13：智能医疗鞋垫
     *                   - 14：心电衣
     *                   - 15：呼吸衣
     *                   - 16：哮喘采集装置
     *                   - 17：拉峰智能裤
     *                   - 18：孕呼吸带
     *                   - 19：智能塑身衣
     *                   - ...等等 具体查看硬件编码规定
     * @return
     */
    @Url(value = "/devices/{vcode}/{category}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<DeviceInfoResult>> getDeviceInfoOpen(@PathVariable("vcode") String vvcode, @PathVariable("category") int deviceType);

    /**
     * 公开的，不需要登陆，获取设备信息
     *
     * @param devIdOrMac 设备ID或Mac地址
     * @return 请求上下文环境
     */
    @Url(value = "/devices/{devIdOrMac}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<DeviceInfoResult>> getDeviceInfoOpen(@PathVariable("devIdOrMac") String devIdOrMac);

    /**
     * 获取设备固件权限
     *
     * @param table 表格文件
     * @param row   行
     * @param a     a1,a2,a3,a4四个值
     * @return 请求上下文环境
     */
    @Url(value = "/my/devices/permissions/{table}", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> getDevPermission(@PathVariable("table") int table,
                                                        @JsonPayload("row") int row,
                                                        @JsonPayload("a") int[] a);


    /**
     * 更新固件版本
     *
     * @param code    设备编号
     * @param version 固件版本
     * @return
     */
    @Url(value = "/my/devices/{code}/firmware/{version}", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult<String>> UpdateVersion(@PathVariable("code") String code,
                                                             @PathVariable("version") String version

    );

    /**
     * 同步应用数据
     *
     * @param category
     * @param format
     * @param payload
     * @return
     */
    @Url(value = "/my/appdatas/{category}/{format}", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<AddAppDataResult>> addAppData(@PathVariable("category") String category,
                                                                    @PathVariable("format") String format,
                                                                    @JsonPayload() AddAppDataPayload payload);

    /**
     * 获取应用数据
     *
     * @param category
     * @param format
     * @param batchNo
     * @return
     */
    @Url(value = "/my/appdatas/{category}/{format}/{batch_no}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<AppDataResult>> getAppData(@PathVariable("category") String category,
                                                                 @PathVariable("format") String format,
                                                                 @PathVariable("batch_no") String batchNo);

    /**
     * 删除应用数据
     *
     * @param category
     * @param format
     * @param batchNo
     * @return
     */
    @Url(value = "/my/appdatas/{category}/{format}/{batch_no}", method = RequestMethod.DELETE)
    CloudRequestContext<RestfulResult> deleteAppData(
            @PathVariable("category") String category,
            @PathVariable("format") String format,
            @PathVariable("batch_no") String batchNo);

    /**
     * 查询应用数据列表
     *
     * @param category
     * @param format
     * @param begin
     * @param end
     * @return
     */
    @Url(value = "/my/appdatas/{category}/{format}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<AppDataResult>>> listAppData(@PathVariable("category") String category,
                                                                        @PathVariable("format") String format,
                                                                        @RequestParam("begin") String begin,
                                                                        @RequestParam("end") String end,
                                                                        @RequestParam("time_zone") String time_zone
    );

    /**
     * 上传原始数据信息
     *
     * @param payload
     * @return
     */
    @Url(value = "/my/devices/raws", method = RequestMethod.POST)
    @Deprecated
    CloudRequestContext<RestfulResult> addRawsFile(@JsonPayload() AddRawsFilePayload payload);

    @Url(value = "/my/devices/raws/latest", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> addRawsFileLast(@JsonPayload() AddRawsFilePayload payload);

    /**
     * 定时任务补计算
     *
     * @param category
     * @param format
     * @return
     */
    @Url(value = "/my/appdatas/supplement/{category}/{format}", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<AddAppDataResult>> supplement(@PathVariable("category") String category,
                                                                    @PathVariable("format") String format);


    /**
     * 申请设备维修
     *
     * @param device_code
     * @param desc
     * @param photos
     * @return
     */
    @Url(value = "/my/devicerepairs", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<String>> applyMaintenance(@JsonPayload("device_code") String device_code,
                                                                @JsonPayload("desc") String desc,
                                                                @JsonPayload("photos") List<String> photos);

    /**
     * 查看设备维修详情
     *
     * @param id
     * @return
     */
    @Url(value = "/my/devicerepairs/{id}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<MaintenanceResult>> getMaintenanceDetail(@PathVariable("id") String id);


    /**
     * 我的设备维修列表
     *
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/my/devicerepairs/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<MaintenanceListResult>> getMaintenanceList(@PathVariable("page") int page,
                                                                                 @RequestParam("size") int size);

    /**
     * 待寄回-填写快递单号
     *
     * @param id
     * @param no                快递单号
     * @param logistics_company 物流公司
     * @return
     */
    @Url(value = "/my/devicerepairs/{id}/expresses/no", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> expressMaintenance(@PathVariable("id") String id,
                                                          @JsonPayload("no") String no,
                                                          @JsonPayload("logistics_company") String logistics_company);

    /**
     * 取消维修
     *
     * @param id
     * @return
     */
    @Url(value = "/my/devicerepairs/{id}/cancel", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> cancelMaintenance(@PathVariable("id") String id);

    /**
     * 确认收货
     *
     * @param id
     * @return
     */
    @Url(value = "/my/devicerepairs/{id}/receipts", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> receiptsMaintenance(@PathVariable("id") String id);

    /**
     * 订单提交
     *
     * @param id
     * @param receiveInfoPayload
     * @return
     */
    @Url(value = "/my/devicerepairs/{id}/orders", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<MyOrderResult>> submitOrder(@PathVariable("id") String id,
                                                                  @JsonPayload() ReceiveInfoPayload receiveInfoPayload);

}
