package hk.advanpro.cloud.api.client;

import java.util.List;

import hk.advanpro.cloud.api.CloudRequestContext;
import hk.advanpro.cloud.api.annotation.Header;
import hk.advanpro.cloud.api.annotation.Headers;
import hk.advanpro.cloud.api.annotation.JsonPayload;
import hk.advanpro.cloud.api.annotation.PathVariable;
import hk.advanpro.cloud.api.annotation.RequestMethod;
import hk.advanpro.cloud.api.annotation.RequestParam;
import hk.advanpro.cloud.api.annotation.Url;
import hk.advanpro.cloud.api.result.RestfulResult;
import hk.advanpro.cloud.api.result.msg.MessageListResult;
import hk.advanpro.cloud.api.result.msg.UnreadMessageResult;

/**
 * 消息中心接口
 * Created by jason on 2019/06/11.
 */

@Headers({
        @Header(name = "Content-Type", value = "application/json")
})
public interface MsgApi extends CloudApi {
    public static final String NAME = "msg";

    /**
     * 我的消息-列表
     *
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/my/messages/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<MessageListResult>> getMyMessagesList(@PathVariable("page") int page,
                                                                            @RequestParam("size") int size);

    /**
     * 我的消息-列表（太极跑）
     *
     * @param page
     * @param size
     * @param category - chirunning_enroll:学员报名通知
     *                 - chirunning_verify:审核通知
     *                 - chirunning_open:开课提醒通知
     *                 - chirunning_signin:签到通知
     * @return
     */
    @Url(value = "/my/messages/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<MessageListResult>> getCoachMessagesList(@PathVariable("page") int page,
                                                                               @RequestParam("size") int size,
                                                                               @RequestParam("category") String category);

    /**
     * 我的消息-标记已读/未读
     *
     * @param id     消息ID
     * @param status - 1:未读
     *               - 2:已读
     * @return
     */
    @Url(value = "/my/messages/{id}/status", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<String>> setMessageStatus(@PathVariable("id") String id,
                                                                @JsonPayload("status") int status);

    /**
     * 我的消息-删除消息
     *
     * @param id
     * @return
     */
    @Url(value = "/my/messages/{id}", method = RequestMethod.DELETE)
    CloudRequestContext<RestfulResult<String>> deleteMessage(@PathVariable("id") String id);

    /**
     * 我的消息-未读记录数
     *
     * @return
     */
    @Url(value = "/my/messages/unread/counts", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<Integer>> getUnreadMessagesCount();

    /**
     * 我的消息-未读记录数(按分类)
     *
     * @param category
     * @return
     */
    @Url(value = "/my/messages/unread/counts/category", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<UnreadMessageResult>>> getUnreadMessagesCountByCategory(@RequestParam("category") String category);

}
