package hk.advanpro.cloud.api.client;

import java.util.List;

import hk.advanpro.cloud.api.CloudRequestContext;
import hk.advanpro.cloud.api.annotation.Header;
import hk.advanpro.cloud.api.annotation.Headers;
import hk.advanpro.cloud.api.annotation.JsonPayload;
import hk.advanpro.cloud.api.annotation.PathVariable;
import hk.advanpro.cloud.api.annotation.RequestMethod;
import hk.advanpro.cloud.api.annotation.RequestParam;
import hk.advanpro.cloud.api.annotation.Url;
import hk.advanpro.cloud.api.payload.oc.OrderRefundItemPayload;
import hk.advanpro.cloud.api.payload.oc.OrderSubmitPayload;
import hk.advanpro.cloud.api.result.ListResult;
import hk.advanpro.cloud.api.result.RestfulResult;
import hk.advanpro.cloud.api.result.oc.CommentListResult;
import hk.advanpro.cloud.api.result.oc.LogisticResult;
import hk.advanpro.cloud.api.result.oc.OrderSubmitResult;
import hk.advanpro.cloud.api.result.oc.ProductListResult;

/**
 * 商城接口
 * Created by jalin on 2018/06/18.
 */

@Headers({
        @Header(name = "Content-Type", value = "application/json")
})
public interface OCApi extends CloudApi {
    public static final String NAME = "oc";


    /**
     * 获取父id下面的两级分类列表
     *
     * @param page 页数
     * @param size 每页数量
     * @return <p>
     * /**
     * 获取商品列表
     */
    @Url(value = "/myshop/products/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<ProductListResult>> getProducts(@PathVariable("page") int page,
                                                                      @RequestParam("size") int size);


    /**
     * 获取商品详情
     *
     * @param id 商品spu主键
     * @return
     */
    @Url(value = "/myshop/products/{id}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult> getProductDetail(@PathVariable("id") String id);

    /**
     * 获取购物车.列表
     *
     * @param page 页码
     * @param size 大小
     * @return
     */
    @Url(value = "/my/carts/list/{page}?size={size}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<ListResult>> getCastsList(@PathVariable("page") int page,
                                                                @PathVariable("size") int size);


    /**
     * 商品评价列表
     *
     * @param spuId spu主键
     * @param page  页码
     * @param size  大小
     * @return
     */
    @Url(value = "/myshop/products/{spu_id}/comments/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<CommentListResult>> getProductComments(@PathVariable("spu_id") long spuId,
                                                                             @PathVariable("page") int page,
                                                                             @RequestParam("size") int size);

    /**
     * 订单提交
     *
     * @param orderPayload
     * @return
     */
    @Url(value = "/my/orders", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<OrderSubmitResult>> orderSubmit(@JsonPayload OrderSubmitPayload orderPayload);


    /**
     * 订单支付
     *
     * @param orderId      订单id
     * @param orderIdAgain 订单id 再次确认
     * @param paymentType  支付类型
     *                     -1:支付宝
     *                     -2:微信
     * @return
     */
    @Deprecated
    @Url(value = "/my/orders/{id}/pay", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult<String>> orderPay(@PathVariable("id") String orderId,
                                                        @JsonPayload("id") String orderIdAgain,
                                                        @JsonPayload("payment_type") int paymentType);

    /**
     * 订单支付
     *
     * @param orderId      订单id
     * @param orderIdAgain 订单id 再次确认
     * @param paymentType  支付类型
     *                     -1:支付宝
     *                     -2:微信
     * @param sign         密钥 id=XXX&payment_type=XXX
     *                     将参数按照以上格式拼接，然后使用RSA加密得到签名字符串
     * @return
     */
    @Url(value = "/my/orders/{id}/pay", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult<String>> orderPay(@PathVariable("id") String orderId,
                                                        @JsonPayload("id") String orderIdAgain,
                                                        @JsonPayload("payment_type") int paymentType,
                                                        @JsonPayload("sign") String sign);


    /**
     * 订单签收
     *
     * @param id 订单id
     * @return
     */
    @Url(value = "/my/orders/{id}/sign", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult> orderSign(@PathVariable("id") String id);

    /**
     * 订单取消(未支付)
     *
     * @param id 订单id
     * @return
     */
    @Url(value = "/my/orders/{id}/produce/close", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> cancelOrder(@PathVariable("id") String id);


    /**
     * 订单取消（已付款）
     *
     * @param id           订单id
     * @param order_id     订单id
     * @param refund_cause 退款原因
     * @return
     */
    @Url(value = "/my/orders/{id}/pay/close", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> cancelPayOrder(@PathVariable("id") String id,
                                                      @JsonPayload("id") String order_id,
                                                      @JsonPayload("refund_cause") String refund_cause);

    /**
     * 订单删除
     *
     * @param id 订单id
     * @return
     */
    @Url(value = "/my/orders/{id}", method = RequestMethod.DELETE)
    CloudRequestContext<RestfulResult> orderDelete(@PathVariable("id") String id);

    /**
     * 申请退款
     *
     * @param id         订单id
     * @param orderItems 退款订单项目
     * @return
     */
    @Url(value = "/my/orders/{id}/refund", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> orderRefund(@PathVariable("id") String id,
                                                   @JsonPayload() OrderRefundItemPayload orderItems);

    /**
     * 订单列表
     *
     * @param status 处理状态 -0：全部
     *               - 5:待付款
     *               - 10:待发货
     *               - 15:待收货
     *               - 20:待评价
     *               - 25:退款/售后
     * @param page   页码
     * @param size   大小
     * @return
     */
    @Url(value = "/my/orders/{status}/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult> getMyOrders(@PathVariable("status") int status,
                                                   @PathVariable("page") int page,
                                                   @RequestParam("size") int size);


    /**
     * 申请退款记录
     *
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/my/orders/sign/egt/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult> getRefundRecord(@PathVariable("page") int page,
                                                       @RequestParam("size") int size);


    /**
     * 订单详情
     *
     * @param id 订单id
     * @return
     */
    @Url(value = "/my/orders/{id}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult> getMyOrder(@PathVariable("id") String id);


    /**
     * 评价商品接口
     *
     * @param id      订单id
     * @param content 评论内容
     * @param photos  评论图片数组
     * @return
     */
    @Url(value = "/my/orders/items/{id}/comments", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> commentSubmit(@PathVariable("id") String id,
                                                     @JsonPayload("content") String content,
                                                     @JsonPayload("photos") List<String> photos);


    /**
     * 我的评价列表
     *
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/my/orders/items/comments/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<CommentListResult>> getMyComments(@PathVariable("page") int page,
                                                                        @RequestParam("size") int size);


    /**
     * 物流详情
     *
     * @param logistic_no 物流编号
     * @return
     */
    @Url(value = "/my/orders/logistics/{logistic_no}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<LogisticResult>> getLogistic(@PathVariable("logistic_no") String logistic_no);


}
