package hk.advanpro.cloud.api.client;

import java.util.List;

import hk.advanpro.cloud.api.CloudRequestContext;
import hk.advanpro.cloud.api.annotation.Header;
import hk.advanpro.cloud.api.annotation.Headers;
import hk.advanpro.cloud.api.annotation.JsonPayload;
import hk.advanpro.cloud.api.annotation.PathVariable;
import hk.advanpro.cloud.api.annotation.RequestMethod;
import hk.advanpro.cloud.api.annotation.RequestParam;
import hk.advanpro.cloud.api.annotation.Url;
import hk.advanpro.cloud.api.payload.qc.DeviceStatus;
import hk.advanpro.cloud.api.payload.qc.DeviceVersion;
import hk.advanpro.cloud.api.result.RestfulResult;
import hk.advanpro.cloud.api.result.qc.DeviceListResult;
import hk.advanpro.cloud.api.result.qc.DeviceResult;
import hk.advanpro.cloud.api.result.qc.OrderListResult;
import hk.advanpro.cloud.api.result.qc.OrderResult;
import hk.advanpro.cloud.api.result.qc.TestProjectResult;

/**
 * 质检接口
 * Created by jason on 2018/7/18
 */

@Headers({
        @Header(name = "Content-Type", value = "application/json")
})
public interface QCApi extends CloudApi {
    public static final String NAME = "qc";

    /**
     * 获取订单列表
     *
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/qc/orders/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<OrderListResult>> getOrderList(@PathVariable("page") int page,
                                                                     @RequestParam("size") int size);

    /**
     * 获取生产订单详情
     *
     * @param id
     * @return
     */
    @Url(value = "/qc/orders/{id}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<OrderResult>> getOrder(@PathVariable("id") String id);

    /**
     * 某个订单的设备列表
     *
     * @param orderId
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/qc/devices/{order_id}/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<DeviceListResult>> getDeviceList(@PathVariable("order_id") String orderId,
                                                                       @PathVariable("page") int page,
                                                                       @RequestParam("size") int size);

    /**
     * 获取检测项详情
     *
     * @param id
     * @return
     */
    @Url(value = "/qc/projects/{id}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<TestProjectResult>> getTestProject(@PathVariable("id") String id);

    /**
     * 查询设备关联信息
     *
     * @param code
     * @param mac
     * @return
     */
    @Url(value = "/qc/devices/{code}/{mac}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<DeviceResult>> getDeviceAssociatedInfo(@PathVariable("code") String code, @PathVariable("mac") String mac);

    /**
     * 设备关联mac地址
     *
     * @param code
     * @param mac
     * @param orderId
     * @return
     */
    @Url(value = "/qc/devices/{code}/mac", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult<DeviceResult>> setDeviceAssociatedInfo(@PathVariable("code") String code, @JsonPayload("mac") String mac, @JsonPayload("order_id") String orderId);

    /**
     * 修改设备版本号信息
     *
     * @param code
     * @return
     */
    @Url(value = "/qc/devices/{code}/version", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult<DeviceResult>> setDeviceVersion(@PathVariable("code") String code, @JsonPayload DeviceVersion deviceVersion);

    /**
     * 修改设备状态
     *
     * @param code
     * @return
     */
    @Url(value = "/qc/devices/{code}/status", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult> setDeviceStatus(@PathVariable("code") String code, @JsonPayload DeviceStatus deviceStatus);

    /**
     * 修改设备写入状态
     *
     * @param code
     * @param deviceStatus
     * @return
     */
    @Url(value = "/qc/devices/{code}/write/status", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult> setWriteStatus(@PathVariable("code") String code, @JsonPayload DeviceStatus deviceStatus);

    /**
     * 获取订单下一条编码
     *
     * @param orderId
     * @param projectId
     * @return
     */
    @Url(value = "/qc/orders/{order_id}/{project_id}/devices/code/next", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<DeviceResult>>> getNextCode(@PathVariable("order_id") String orderId,
                                                                       @PathVariable("project_id") String projectId);

    /**
     * 获取订单上一次编码
     *
     * @param orderId
     * @param projectId
     * @return
     */
    @Url(value = "/qc/orders/{order_id}/{project_id}/devices/code/lately", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<DeviceResult>>> getPreviousCode(@PathVariable("order_id") String orderId,
                                                                           @PathVariable("project_id") String projectId);

    /**
     * 设备已检测过的检测项
     *
     * @param code
     * @param projectId
     * @return
     */
    @Url(value = "/qc/devices/{code}/projects/{project_id}", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult> setProjectStatus(@PathVariable("code") String code, @PathVariable("project_id") String projectId);

}
