package hk.advanpro.cloud.api.client;

import java.util.Date;
import java.util.List;

import hk.advanpro.cloud.api.CloudRequestContext;
import hk.advanpro.cloud.api.annotation.Header;
import hk.advanpro.cloud.api.annotation.Headers;
import hk.advanpro.cloud.api.annotation.RequestMethod;
import hk.advanpro.cloud.api.annotation.RequestParam;
import hk.advanpro.cloud.api.annotation.Url;
import hk.advanpro.cloud.api.result.RestfulResult;
import hk.advanpro.cloud.api.result.sac.DailyStepsResult;
import hk.advanpro.cloud.api.result.sac.RunStatisticResult;
import hk.advanpro.cloud.api.result.sac.WalkGaitResult;
import hk.advanpro.cloud.api.result.sac.MonthStepsResult;

/**
 * Created by jalin on 2017/10/13.
 */

@Headers({
        @Header(name = "Content-Type", value = "application/json")
})
public interface SACApi extends CloudApi {
    public static final String NAME = "sac";

    /**
     * 按天获取用户的日统计步数
     *
     * @param begin 开始时间
     * @param end   结束时间
     * @return 请求上下文环境
     */
    @Url(value = "/my/walks/steps/daily", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<DailyStepsResult>>> getWalkStepsByDaily(@RequestParam("begin") String begin,
                                                                                   @RequestParam("end") String end);


    /**
     * 按月获取用户的日统计步数
     *
     * @param begin 开始时间
     * @param end   结束时间
     * @return 请求上下文环境
     */
    @Url(value = "/my/walks/steps/month", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<MonthStepsResult>>> getWalkStepsByMonth(@RequestParam("begin") String begin,
                                                                                   @RequestParam("end") String end);


    /**
     * 获取用户的日统计步态
     *
     * @param begin 开始时间
     * @param end   结束时间
     * @return 请求上下文环境
     */
    @Url(value = "/my/walks/gait", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<WalkGaitResult>> getWalkGaits(@RequestParam("begin") String begin,
                                                                    @RequestParam("end") String end);

    /**
     * 获取用户的日分段步数
     *
     * @param date 开始时间
     * @return 请求上下文环境
     */
    @Url(value = "/my/walks/sections", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult> getWalkSections(@RequestParam("date") String date);


    /**
     * 获取用户的活动日期列表
     *
     * @return 请求上下文环境
     */
    @Url(value = "/my/walks/dates", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<Date>>> getWalkDates();


    /**
     * 获取用户最近几次跑步数据
     *
     * @return 请求上下文环境
     */
    @Url(value = "/my/runs/statistic", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<RunStatisticResult>> getRunStatistic();

    /**
     * 获取用户最近几次跑步数据
     *
     * @param size 获取次数
     * @return 请求上下文环境
     */
    @Url(value = "/my/runs/recent/times", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult> getRunRecentTimes(@RequestParam("size") int size);

}
