package hk.advanpro.cloud.api.client;

import java.util.List;

import hk.advanpro.cloud.api.CloudRequestContext;
import hk.advanpro.cloud.api.annotation.Header;
import hk.advanpro.cloud.api.annotation.Headers;
import hk.advanpro.cloud.api.annotation.JsonPayload;
import hk.advanpro.cloud.api.annotation.PathVariable;
import hk.advanpro.cloud.api.annotation.RequestMethod;
import hk.advanpro.cloud.api.annotation.RequestParam;
import hk.advanpro.cloud.api.annotation.Url;
import hk.advanpro.cloud.api.payload.soc.ChannelsActionPayload;
import hk.advanpro.cloud.api.payload.soc.ChannelsPayload;
import hk.advanpro.cloud.api.payload.soc.ChatConfigPayload;
import hk.advanpro.cloud.api.payload.soc.CreateContactsPayload;
import hk.advanpro.cloud.api.payload.soc.PeopleInitPayload;
import hk.advanpro.cloud.api.payload.soc.PeoplePayload;
import hk.advanpro.cloud.api.payload.soc.PostsPayload;
import hk.advanpro.cloud.api.payload.soc.SendPostOrCommentsPayload;
import hk.advanpro.cloud.api.payload.soc.TagsPayload;
import hk.advanpro.cloud.api.result.RestfulResult;
import hk.advanpro.cloud.api.result.soc.ChannelsResult;
import hk.advanpro.cloud.api.result.soc.ChatConfigResult;
import hk.advanpro.cloud.api.result.soc.CommentListResult;
import hk.advanpro.cloud.api.result.soc.CommentsResult;
import hk.advanpro.cloud.api.result.soc.ContactsInfoResult;
import hk.advanpro.cloud.api.result.soc.ContactsListResult;
import hk.advanpro.cloud.api.result.soc.FollowerPeoplesResult;
import hk.advanpro.cloud.api.result.soc.GroupInfoResult;
import hk.advanpro.cloud.api.result.soc.GroupMemberListResult;
import hk.advanpro.cloud.api.result.soc.GroupMemberResult;
import hk.advanpro.cloud.api.result.soc.GroupsResult;
import hk.advanpro.cloud.api.result.soc.InitSocialResult;
import hk.advanpro.cloud.api.result.soc.InteractiveMessageListResult;
import hk.advanpro.cloud.api.result.soc.IsUserExitsResult;
import hk.advanpro.cloud.api.result.soc.PeoplesListResult;
import hk.advanpro.cloud.api.result.soc.PostGroupListResult;
import hk.advanpro.cloud.api.result.soc.PostListResult;
import hk.advanpro.cloud.api.result.soc.PostsResult;
import hk.advanpro.cloud.api.result.soc.PrenatalPeoplesListResult;
import hk.advanpro.cloud.api.result.soc.RecommendPeopleResult;
import hk.advanpro.cloud.api.result.soc.TagsResult;
import hk.advanpro.cloud.api.result.soc.UserProfileResult;

/**
 * 社交接口
 * Created by jason on 2018/7/3
 */

@Headers({
        @Header(name = "Content-Type", value = "application/json")
})
public interface SOCApi extends CloudApi {

    /**
     * 删除
     */
    public static final int STATUS_DELETE = 0;
    /**
     * 正常
     */
    public static final int STATUS_NORMAL = 1;
    /**
     * 屏蔽
     */
    public static final int STATUS_SHIELD = 2;

    /**
     * 关注人
     */
    public static final int ACTION_FOLLOWING = 1;
    /**
     * 取消关注人
     */
    public static final int ACTION_UNFOLLOWING = 2;
    /**
     * 点赞帖子
     */
    public static final int ACTION_FAVOUR = 3;
    /**
     * 取消点赞帖子
     */
    public static final int ACTION_UNFAVOUR = 4;
    /**
     * 拉黑 人
     */
    public static final int ACTION_BLACKENED = 5;
    /**
     * 取消拉黑 人
     */
    public static final int ACTION_UNBLACKENED = 6;
    /**
     * 举报 人
     */
    public static final int ACTION_REPORTED = 7;
    /**
     * 取消举报 人
     */
    public static final int ACTION_UNREPORTED = 8;

    /**
     * 收藏帖子
     */
    public static final int ACTION_COLLECTED = 11;
    /**
     * 取消收藏帖子
     */
    public static final int ACTION_UNCOLLECTED = 12;
    /**
     * 踩帖子
     */
    public static final int ACTION_DISCOUNTED = 17;
    /**
     * 取消踩帖子
     */
    public static final int ACTION_UNDISCOUNTED = 18;
    /**
     * 分享
     */
    public static final int ACTION_SHARED = 19;
    /**
     * 删除帖子
     */
    public static final int ACTION_DELETE = 0;

    public static final String NAME = "soc";

    /**
     * 社交用户是否存在
     *
     * @return
     */
    @Url(value = "my/exist", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<IsUserExitsResult>> isUserExist();

    /**
     * 社交用户初始化
     *
     * @param payload
     * @return
     */
    @Url(value = "my/init", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<InitSocialResult>> init(@JsonPayload() PeopleInitPayload payload);

    /**
     * 获取个人主页(自己)
     *
     * @return
     */
    @Url(value = "/my/profile", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<UserProfileResult>> getMyProfile();

    /**
     * 获取我的粉丝/关注/举报/拉黑列表
     *
     * @param page 页码
     * @param size 页内大小
     * @param type 类型
     *             - 0:我关注的
     *             - 1:我的粉丝
     *             - 2:我拉黑的人
     *             - 3:我举报的人
     * @return
     */
    @Url(value = "/my/peoples/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<PeoplesListResult>> getMyPeoples(@PathVariable("page") int page,
                                                                       @RequestParam("size") int size,
                                                                       @RequestParam("type") int type);


    /**
     * 获取我发的/举报/收藏/赞的帖子
     *
     * @param page 页码
     * @param size 页内大小
     * @param type 类型
     *             - 0:我发布的
     *             - 7:举报
     *             - 11:收藏
     *             - 3:赞
     * @return
     */
    @Url(value = "/my/posts/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<PostListResult>> getMyPosts(@PathVariable("page") int page,
                                                                  @RequestParam("size") int size,
                                                                  @RequestParam("type") int type);

    /**
     * 获取我/举报/收藏/赞的帖子（按月分组）
     *
     * @param page
     * @param size
     * @param type type:int:类型
     *             - 3:赞
     *             - 7:举报
     *             - 11:收藏
     *             - 17:踩
     * @return
     */
    @Url(value = "/my/posts/group/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<PostGroupListResult>> getMyPostsGroup(@PathVariable("page") int page,
                                                                            @RequestParam("size") int size,
                                                                            @RequestParam("type") int type);

    /**
     * 获取我的帖子墙
     *
     * @param page 页码
     * @param size 页内大小
     * @return
     */
    @Url(value = "/my/timeline/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<PostListResult>> getMyPostsTimeLine(@PathVariable("page") int page,
                                                                          @RequestParam("size") int size);


    /**
     * 关注/取消关注/举报/拉黑他人
     *
     * @param accountSetPayload
     * @return
     */
    @Url(value = "/my/peoples", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult> setMyPeoples(@JsonPayload PeoplePayload accountSetPayload);

    /**
     * 进入/退出频道
     *
     * @param channelSetPayload
     * @return
     */
    @Url(value = "/my/channels", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult> setChannels(@JsonPayload ChannelsActionPayload channelSetPayload);


    @Url(value = "/posts/{id}", method = RequestMethod.DELETE)
    CloudRequestContext<RestfulResult> deleteMyPost(@PathVariable("id") String id);

    /**
     * 点赞/收藏/举报/踩帖子帖子
     *
     * @param id
     * @param postSetPayload
     * @return
     */
    @Url(value = "/my/posts/{id}", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult> setPosts(@PathVariable("id") String id,
                                                @JsonPayload PostsPayload postSetPayload);

    /**
     * 达成标签
     *
     * @param id 标签主键
     * @return
     */
    @Url(value = "/my/tags/{id}", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult> setTags(@PathVariable("id") String id);

    /**
     * 获取个人主页(他人)
     *
     * @return
     */
    @Url(value = "/profile/{id}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<UserProfileResult>> getOthersProfile(@PathVariable("id") String id);

    /**
     * 获取个人发帖列表
     *
     * @param author
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/posts/{author}/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<PostListResult>> getOtherPosts(@PathVariable("author") String author,
                                                                     @PathVariable("page") int page,
                                                                     @RequestParam("size") int size);

    /**
     * 频道是否存在
     *
     * @param code
     * @return
     */
    @Url(value = "/channels/{code}/exist", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<String>> isChannelsExits(@PathVariable("code") String code);

    /**
     * 根据名称获取频道
     *
     * @param code
     * @return
     */
    @Url(value = "/channels/{code}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<ChannelsResult>> getChannel(@PathVariable("code") String code);

    /**
     * 发帖/转发/评论
     *
     * @param postsSendPayload
     * @return
     */
    @Url(value = "/posts", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> sendPosts(@JsonPayload SendPostOrCommentsPayload postsSendPayload);

    /**
     * 获取帖子详情
     *
     * @param id
     * @return
     */
    @Url(value = "/posts/{id}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<PostsResult>> getPostsDetail(@PathVariable("id") String id);

    /**
     * 获取所有帖子列表
     *
     * @param page
     * @param size
     * @param channel 频道主键
     * @param filter  筛选条件
     * @param keyword
     * @return
     */
    @Url(value = "/posts/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<PostListResult>> getOtherPosts(@PathVariable("page") int page,
                                                                     @RequestParam("size") int size,
                                                                     @RequestParam("channel") String channel,
                                                                     @RequestParam("filter") String filter,
                                                                     @RequestParam("keyword") String keyword);

    /**
     * 获取帖子或评论下级评论列表
     *
     * @param id    帖子或评论主键
     * @param page
     * @param size
     * @param csize 评论下子评论条数(评论下需要带子评论时需要)
     * @return
     */
    @Url(value = "/posts/{id}/comments/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<CommentListResult>> getComments(@PathVariable("id") String id,
                                                                      @PathVariable("page") int page,
                                                                      @RequestParam("size") int size,
                                                                      @RequestParam("csize") int csize);

    /**
     * 获取我关注的用户帖子列表
     *
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/posts/list/attention/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<PostListResult>> getAttentionPosts(@PathVariable("page") int page,
                                                                         @RequestParam("size") int size,
                                                                         @RequestParam("filters") String filters,
                                                                         @RequestParam("keyword") String keyword);

    /**
     * 获取热门帖子列表
     *
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/posts/list/popular/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<PostListResult>> getPopularPosts(@PathVariable("page") int page,
                                                                       @RequestParam("size") int size);

    /**
     * 获取推荐帖子列表
     *
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/posts/list/recommand/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<PostListResult>> getRecommandPosts(@PathVariable("page") int page,
                                                                         @RequestParam("size") int size);

    //---------- 即时通讯 ----------

    /**
     * 新建联系人
     *
     * @param id
     * @param createContactsPayload
     * @return
     */
    @Url(value = "/my/contacts/{id}", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<ContactsInfoResult>> newContacts(@PathVariable("id") String id, @JsonPayload CreateContactsPayload createContactsPayload);


    /**
     * 修改联系人
     *
     * @param id
     * @param createContactsPayload
     * @return
     */
    @Url(value = "/my/contacts/{id}", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult> updateMyContactConfig(@PathVariable("id") String id, @JsonPayload ChatConfigPayload createContactsPayload);

    /**
     * 获取联系人信息
     *
     * @param id
     * @return
     */
    @Url(value = "/my/contacts/{id}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<ContactsInfoResult>> getContactInfo(@PathVariable("id") String id);

    /**
     * 删除联系人
     *
     * @param id
     * @return
     */
    @Url(value = "/my/contacts/{id}", method = RequestMethod.DELETE)
    CloudRequestContext<RestfulResult> deleteContacts(@PathVariable("id") String id);

    /**
     * 联系人列表
     *
     * @param page
     * @param size
     * @param keyword
     * @return
     */
    @Url(value = "/my/contacts/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<ContactsListResult>> getContactsList(@PathVariable("page") int page,
                                                                           @RequestParam("size") int size,
                                                                           @RequestParam("keyword") String keyword);

    /**
     * 获取我的群信息配置
     *
     * @param id
     * @return
     */
    @Url(value = "/my/groups/{id}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<ChatConfigResult>> getMyGroupConfig(@PathVariable("id") String id);

    /**
     * 更新我的群配置
     *
     * @param id
     * @return
     */
    @Url(value = "/my/groups/{id}", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult<ChatConfigResult>> updateMyGroupConfig(@PathVariable("id") String id,
                                                                             @JsonPayload ChatConfigPayload config);

    /**
     * 进群
     *
     * @param id
     * @return
     */
    @Url(value = "/my/groups/{id}", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> joinGroup(@PathVariable("id") String id, @JsonPayload ChatConfigPayload config);

    /**
     * 退群
     *
     * @param id
     * @return
     */
    @Url(value = "/my/groups/{id}", method = RequestMethod.DELETE)
    CloudRequestContext<RestfulResult> quitGroup(@PathVariable("id") String id);

    /**
     * 群列表
     *
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/my/groups/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<GroupsResult>>> getGroupsList(@PathVariable("page") int page,
                                                                         @RequestParam("size") int size);

    // --------- 群 ----

    /**
     * 获取群详情
     *
     * @param id
     * @return
     */
    @Url(value = "/groups/{id}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<GroupInfoResult>> getGroupInfo(@PathVariable("id") String id);

    /**
     * 获取群内成员信息
     *
     * @param group_id
     * @param id
     * @return
     */
    @Url(value = "/groups/{group_id}/members/{id}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<GroupMemberResult>> getGroupUserInfo(@PathVariable("group_id") String group_id,
                                                                           @PathVariable("id") String id);

    /**
     * 解释群组
     *
     * @param id
     * @return
     */
    @Url(value = "/groups/{id}", method = RequestMethod.DELETE)
    CloudRequestContext<RestfulResult> deleteGroup(@PathVariable("id") String id);

    /**
     * 新建群
     *
     * @param name
     * @param icon
     * @param type
     * @param config
     * @return
     */
    @Url(value = "/groups", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<String>> createGroup(
            @JsonPayload("type") int type, @JsonPayload("name") String name,
            @JsonPayload("icon") String icon,
            @JsonPayload("config") ChatConfigPayload config);

    /**
     * 把用户拉进群（需要群主权限）
     *
     * @param id
     * @param users
     * @return
     */
    @Url(value = "/groups/{id}/join", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> addUserIntoGroupByOwner(@PathVariable("id") String id, @JsonPayload("users") List<String> users);

    /**
     * 把用户拉除群（需要群主权限）
     *
     * @param id
     * @param users
     * @return
     */
    @Url(value = "/groups/{id}/leave", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> deleteUserFromGroupByOwner(@PathVariable("id") String id, @JsonPayload("users") List<String> users);


    /**
     * 获取群内成员列表
     *
     * @param id
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/groups/{id}/members/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<GroupMemberListResult>> getGroupMembers(@PathVariable("id") String id,
                                                                              @PathVariable("page") int page,
                                                                              @RequestParam("size") int size);


    /**
     * 更新群配置（需要群主权限）
     *
     * @param id     群id
     * @param name   群名字
     * @param icon   群图标
     * @param type   性质
     *               - 0:普通群
     *               - 1:亲密群
     * @param config 第三方群配置
     * @return
     */
    @Url(value = "/groups/{id}", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult> updateGroupInfoByOwner(@JsonPayload("type") int type,
                                                              @PathVariable("id") String id,
                                                              @JsonPayload("name") String name,
                                                              @JsonPayload("icon") String icon,
                                                              @JsonPayload("config") Object config);

    /**
     * 获取一级用户列表（孕友之家）
     *
     * @param page
     * @param size
     * @param filters
     * @param keyword
     * @return
     */
    @Url(value = "/groups/stair/user/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<PrenatalPeoplesListResult>> getPrenatalFriends(@PathVariable("page") int page,
                                                                                     @RequestParam("size") int size,
                                                                                     @RequestParam("filters") String filters,
                                                                                     @RequestParam("keyword") String keyword);

    // -----------   服务号接口      ----------

    /**
     * 修改帖子状态
     *
     * @param id     帖子主键
     * @param status 状态
     *               - 0:删除
     *               - 1:正常
     *               - 2:屏蔽
     * @return
     */
    @Url(value = "/mypos/posts/{id}", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult<PostListResult>> setMyPost(@PathVariable("id") String id,
                                                                 @RequestParam("status") int status);

    /**
     * 创建标签
     *
     * @param tagsPayload
     * @return
     */
    @Url(value = "/mypos/tags", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> newTags(@JsonPayload TagsPayload tagsPayload);

    /**
     * 新建频道
     *
     * @param channelsPayload
     * @return
     */
    @Url(value = "/mypos/channels", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<String>> newChannels(@JsonPayload ChannelsPayload channelsPayload);

    /**
     * 新建频道
     *
     * @param id
     * @return
     */
    @Url(value = "/mypos/channels/{id}", method = RequestMethod.DELETE)
    CloudRequestContext<RestfulResult> deleteChannels(@PathVariable("id") String id);

    /**
     * 修改频道
     *
     * @param id
     * @param channelsPayload
     * @return
     */
    @Url(value = "/mypos/channels/{id}", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult<String>> modifyChannels(@PathVariable("id") String id,
                                                              @JsonPayload ChannelsPayload channelsPayload);


    /**
     * 获取频道详情
     *
     * @param id
     * @return
     */
    @Url(value = "/mypos/channels/{id}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<ChannelsPayload>> getChannelsDetail(@PathVariable("id") String id);

    /**
     * 获取频道列表
     *
     * @param page
     * @param size
     * @param keyword
     * @return
     */
    @Url(value = "/mypos/channels/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<ChannelsPayload>> getChannels(@PathVariable("page") int page,
                                                                    @RequestParam("size") int size,
                                                                    @RequestParam("keyword") String keyword);

    /**
     * 获取帖子或评论下级评论列表(mypos)
     *
     * @param id    帖子或评论主键
     * @param page
     * @param size
     * @param csize 评论下子评论条数(评论下需要带子评论时需要)
     * @return
     */
    @Url(value = "/mypos/posts/{id}/comments/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<CommentsResult>>> getMyposComments(@PathVariable("id") String id,
                                                                              @PathVariable("page") int page,
                                                                              @RequestParam("size") int size,
                                                                              @RequestParam("csize") int csize);

    /**
     * 获取角色列表
     *
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/mypos/roles/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<CommentsResult>>> getRoles(@PathVariable("page") int page,
                                                                      @RequestParam("size") int size);

    /**
     * 获取所有标签列表
     *
     * @return
     */
    @Url(value = "/mypos/tags", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<TagsResult>>> getTags();


    /**
     * 获取我的所有帖子列表(mypos)
     *
     * @param page
     * @param size
     * @param channel 频道主键
     * @return
     */
    @Url(value = "/mypos/posts/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<PostListResult>> getOtherPosts(@PathVariable("page") int page,
                                                                     @RequestParam("size") int size,
                                                                     @RequestParam("channel") String channel);

    /**
     * 获取所有帖子列表
     *
     * @param page
     * @param size
     * @param filters
     * @param keyword
     * @return
     */
    @Url(value = "/posts/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<PostListResult>> getFiltersPosts(@PathVariable("page") int page,
                                                                       @RequestParam("size") int size,
                                                                       @RequestParam("filters") String filters,
                                                                       @RequestParam("keyword") String keyword);

    /**
     * 根据标签编码获取帖子详情
     *
     * @param code
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/posts/labels/{code}/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<PostListResult>> getPostsByTags(@PathVariable("code") String code,
                                                                      @PathVariable("page") int page,
                                                                      @RequestParam("size") int size);

    /**
     * 获取用户关注/粉丝列表
     *
     * @param id      个人主键
     * @param page    页码
     * @param size    页内大小
     * @param type    类型
     *                - 0:关注
     *                - 1:粉丝
     * @param keyword 筛选关键字
     * @return
     */
    @Url(value = "/profile/{id}/peoples/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<FollowerPeoplesResult>>> getPeoples(@PathVariable("id") String id,
                                                                               @PathVariable("page") int page,
                                                                               @RequestParam("size") int size,
                                                                               @RequestParam("type") int type,
                                                                               @RequestParam("keyword") String keyword);


    /**
     * 获取推荐用户列表
     *
     * @param size
     * @return
     */

    @Url(value = "/users/recommand/list", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<RecommendPeopleResult>>> getRecommandPeoples(@RequestParam("size") int size);


    /**
     * 获取融云token
     *
     * @return
     */
    @Url(value = "/ronghub/token", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<String>> getRongCloudToken();

    /**
     * 获取融云推送快照（互动消息）
     *
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/my/snapshots/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<InteractiveMessageListResult>> getInteractiveMessage(@PathVariable("page") int page,
                                                                                           @RequestParam("size") int size);

}
