package hk.advanpro.cloud.api.client;

import com.alibaba.fastjson.JSONObject;

import java.util.List;

import hk.advanpro.cloud.api.CloudRequestContext;
import hk.advanpro.cloud.api.annotation.Header;
import hk.advanpro.cloud.api.annotation.Headers;
import hk.advanpro.cloud.api.annotation.JsonPayload;
import hk.advanpro.cloud.api.annotation.PathVariable;
import hk.advanpro.cloud.api.annotation.RequestMethod;
import hk.advanpro.cloud.api.annotation.RequestParam;
import hk.advanpro.cloud.api.annotation.Url;
import hk.advanpro.cloud.api.payload.MyFeedbackPayload;
import hk.advanpro.cloud.api.payload.PutMyProfilePayload;
import hk.advanpro.cloud.api.payload.QuickLoginPayload;
import hk.advanpro.cloud.api.payload.UserRegisterPayload;
import hk.advanpro.cloud.api.payload.uc.AddressPayload;
import hk.advanpro.cloud.api.payload.uc.TripNotify;
import hk.advanpro.cloud.api.result.RestfulResult;
import hk.advanpro.cloud.api.result.uc.AccountAuthResult;
import hk.advanpro.cloud.api.result.uc.AddressResult;
import hk.advanpro.cloud.api.result.uc.BranchResult;
import hk.advanpro.cloud.api.result.uc.CoachListResult;
import hk.advanpro.cloud.api.result.uc.CoachResult;
import hk.advanpro.cloud.api.result.uc.CustomerServiceResult;
import hk.advanpro.cloud.api.result.uc.GetMyProfileResult;
import hk.advanpro.cloud.api.result.uc.InviteCodeResult;
import hk.advanpro.cloud.api.result.uc.LoginResult;
import hk.advanpro.cloud.api.result.uc.LoginResult_v1;
import hk.advanpro.cloud.api.result.uc.MyPointDetailListResult;
import hk.advanpro.cloud.api.result.uc.MyPointDetailResult;
import hk.advanpro.cloud.api.result.uc.MyPointResult;

/**
 * 用于云端用户中心的访问接口定义。
 * Created by yejianfei on 2017/8/12.
 */
@Headers({
        @Header(name = "Content-Type", value = "application/json")
})
public interface UCApi extends CloudApi {
    public static final String NAME = "uc";

    /**
     * 注册新用户的请求接口
     *
     * @param payload 用户注册信息
     * @return 请求上下文
     */
    @Url(value = "app/register", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<LoginResult>> register(@JsonPayload() UserRegisterPayload payload);

    /**
     * 判断账号是否已存在
     * 该方法已经废弃，请使用 isAccountExists(account)
     *
     * @param account 账号
     * @return
     */
    @Url(value = "/app/account/exists", method = RequestMethod.POST)
    @Deprecated
    CloudRequestContext<RestfulResult<Boolean>> isWxExists(@JsonPayload("account") String account);

    /**
     * 判断账号是否已存在
     *
     * @param account 账号
     * @return
     */
    @Url(value = "/app/account/exists", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<Boolean>> isAccountExists(@JsonPayload("account") String account);

    /**
     * 用户登录请求接口2.0,目前只对孕呼吸
     *
     * @param account   登录账号
     * @param passwd    登录密码
     * @param loginType 登录方式
     *                  - 0:密码登录方式-适合账号、邮箱
     *                  - 1:验证码登录方式
     *                  - 3:微信登录方式
     *                  - 4:QQ登录方式
     * @param appCode   经过RSA的公钥加密字符串;目前只对孕呼吸
     * @return 请求上下文环境
     */
    @Url(value = "/login", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<LoginResult>> login(
            @JsonPayload("account") String account,
            @JsonPayload("passwd") String passwd,
            @JsonPayload("login_type") int loginType,
            @JsonPayload("app_code") String appCode);


    /**
     * 兼容Unifitapp数据格式
     *
     * @param account 登录账号
     * @param passwd  登录密码
     * @return
     */
    @Url(value = "/login", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<LoginResult_v1>> login(
            @JsonPayload("account") String account,
            @JsonPayload("passwd") String passwd);

    /**
     * token续期
     *
     * @return 请求上下文
     */
    @Url(value = "/my/token", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<LoginResult>> keepToken();


    /**
     * 用户退出
     *
     * @return 请求上下文
     */
    @Url(value = "/logout", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> logout();


    /**
     * 修改登录密码
     *
     * @param passwd    当前密码
     * @param newPasswd 新密码
     * @return 请求上下文
     */
    @Url(value = "/my/passwd", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult> changeMyPasswd(
            @JsonPayload("passwd") String passwd,
            @JsonPayload("new_passwd") String newPasswd);


    /**
     * 修改密码-验证码
     *
     * @param vcode     手机验证码
     * @param newPasswd 新密码
     * @return 请求上下文
     */
    @Url(value = "/my/passwd/{vcode}", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult> changeMyPasswdByVCode(
            @PathVariable("vcode") String vcode,
            @JsonPayload("new_passwd") String newPasswd);


    /**
     * 获取个人资料
     *
     * @return 请求上下文环境
     */
    @Url(value = "/my/profiles", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<GetMyProfileResult>> getMyProfile();


    /**
     * 修改个人资料
     *
     * @param payload 登录用户基本信息
     * @return 请求上下文
     */
    @Url(value = "/my/profiles", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult> setMyProfile(@JsonPayload() PutMyProfilePayload payload);


    /**
     * 发送验证码-对于未登录的用户
     *
     * @param account     账号
     * @param accountType 账号类型
     *                    - 0:账号
     *                    - 1:手机
     *                    - 2:邮件
     * @param lang        语言类型
     *                    - en: 英文
     *                    - zh_CN: 简体中文
     * @return 请求上下文环境
     */
    @Url(value = "/vcode", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> sendVCode(
            @JsonPayload("account") String account,
            @JsonPayload("account_type") int accountType,
            @JsonPayload("lang") String lang);

    @Url(value = "/vcode", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> sendVCode(
            @JsonPayload("code") String code,
            @JsonPayload("account") String account,
            @JsonPayload("account_type") int accountType,
            @JsonPayload("lang") String lang);


    /**
     * 校验验证码是否正确-对于未登录的用户
     *
     * @param code    待验证的验证码
     * @param account 用户账号;包含邮箱,手机,账号
     * @return 请求上下文环境
     */
    @Url(value = "/vcode/{code}", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> checkVCode(
            @PathVariable("code") String code,
            @JsonPayload("account") String account);

    /**
     * 忘记密码请求接口。
     *
     * @param account 手机、邮箱地址及微信unionid等
     * @param passwd  新密码
     * @param vCode   验证码
     * @return 请求上下文环境
     */
    @Url(value = "/forgot", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> forgot(
            @JsonPayload("account") String account,
            @JsonPayload("passwd") String passwd,
            @JsonPayload("vcode") String vCode);


    /**
     * 个人资料-绑定账号列表
     *
     * @return
     */
    @Url(value = "/my/bind/list", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<AccountAuthResult>>> accountAuthsList();

    /**
     * 获取我的收获地址列表
     *
     * @return
     */
    @Url(value = "/my/address", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<AddressResult>>> myAddressList();

    /**
     * 新增收获地址
     *
     * @return
     */
    @Url(value = "/my/address", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<String>> addAddress(
            @JsonPayload() AddressPayload addressPayload);

    /**
     * 删除收货地址信息
     *
     * @param id 收货地址id
     * @return
     */
    @Url(value = "/my/address/{id}", method = RequestMethod.DELETE)
    CloudRequestContext<RestfulResult> deleteAddress(@PathVariable("id") String id);

    /**
     * 获取收货地址信息
     *
     * @param id 收货地址id
     * @return
     */
    @Url(value = "/my/address/{id}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<AddressResult>> getAddress(@PathVariable("id") String id);

    /**
     * 修改收货地址
     *
     * @return
     */
    @Url(value = "/my/address/{id}", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult> updateAddress(
            @PathVariable("id") String id,
            @JsonPayload() AddressPayload addressPayload);

    /**
     * 设置默认收货地址
     *
     * @return
     */
    @Url(value = "/my/address/{id}/default", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> setDefaultAddress(
            @PathVariable("id") String id,
            @JsonPayload("is_default") boolean isDefault);


    /**
     * 个人资料-绑定手机
     *
     * @param phone  手机号
     * @param vcode  验证码
     * @param passwd 密码
     * @return
     */
    @Url(value = "/my/bind/phone", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> bindPhone(
            @JsonPayload("phone") String phone,
            @JsonPayload("vcode") String vcode,
            @JsonPayload("passwd") String passwd);

    /**
     * 个人资料-更换手机
     *
     * @param oldPhone 旧手机号
     * @param newPhone 新手机号
     * @param newVcode 新手机号验证码
     * @return
     */
    @Url(value = "/my/change/phone", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult> changePhone(
            @JsonPayload("old_phone") String oldPhone,
            @JsonPayload("new_phone") String newPhone,
            @JsonPayload("new_vcode") String newVcode);

    /**
     * 个人资料-获取绑定的手机号码
     *
     * @return
     */
    @Url(value = "/my/bind/phone", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<String>> getBindPhone();

    /**
     * 个人资料-绑定微信
     *
     * @param unionid  微信的unionid
     * @param nickName 微信昵称
     * @param photo    头像
     * @return
     */
    @Url(value = "/my/bind/wx", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> bindWechar(
            @JsonPayload("unionid") String unionid,
            @JsonPayload("nick_name") String nickName,
            @JsonPayload("photo") String photo);


    /**
     * 个人资料-解绑微信
     *
     * @param unionid
     * @return
     */
    @Url(value = "/my/unbind/wx", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> unbindWechar(
            @JsonPayload("unionid") String unionid);

    /**
     * 个人资料-绑定外部账号
     *
     * @param type     账号类型
     *                 - 0:账号
     *                 - 1:手机
     *                 - 2:邮箱
     *                 - 3:微信
     *                 - 4:QQ
     * @param account  QQ的unionid
     * @param nickName QQ昵称
     * @param photo    头像
     * @return
     */
    @Url(value = "/my/bind/account", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> bindAccount(
            @JsonPayload("type") int type,
            @JsonPayload("account") String account,
            @JsonPayload("nick_name") String nickName,
            @JsonPayload("photo") String photo);


    /**
     * 个人资料-解绑外部账号
     *
     * @param account
     * @return
     */
    @Url(value = "/my/unbind/account", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> unbindAccount(
            @JsonPayload("type") int type,
            @JsonPayload("account") String account);


    //-----------   拉风智能裤  -----------

    /**
     * 跌倒发送短信提醒接口
     *
     * @param tripNotify
     * @return
     */
    @Url(value = "/my/trip/notify", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> tripNotify(@JsonPayload() TripNotify tripNotify);

    //-----------   邀请码  -----------

    /**
     * 生成邀请码
     * <p>
     * 邀请码有效期30分钟，超时或注册完失效
     *
     * @param inviteCode 邀请码
     * @return
     */
    @Url(value = "/invites/codes", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<String>> createInviteCode(@JsonPayload() InviteCodeResult inviteCode);


    /**
     * 根据邀请码获取邀请信息
     *
     * @param code 邀请码
     * @return
     */
    @Url(value = "/invites/codes/{code}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<InviteCodeResult>> getInviteCode(@PathVariable("code") String code);


    /**
     * 使用邀请码注册用户
     *
     * @param from_user 邀请人的社交主键
     * @param role      二级用户角色标签
     * @param mascot    吉祥物编号
     * @return
     */
    @Url(value = "/invites/register", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> registerByInviteCode(@JsonPayload("from_user") String from_user,
                                                            @JsonPayload("role") String role,
                                                            @JsonPayload("mascot") String mascot);


    /**
     * 获取百度开放云的令牌
     *
     * @param id 客户端的ID
     * @return
     */
    @Url(value = "/bce/access_token/{client_id}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<JSONObject>> getBceAccessToken(@PathVariable("client_id") String id);

    /**
     * 添加用户反馈的请求接口
     * <p>
     * UC v2.0废弃
     *
     * @return 请求上下文
     */
    @Deprecated
    @Url(value = "/my/feedbacks", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<Boolean>> addMyFeedbacks(
            @JsonPayload() MyFeedbackPayload payload);


    // ----------- ADK  ------------

    /**
     * 快速登录
     *
     * @param payload
     * @return 请求上下文
     */
    @Url(value = "/quicklogin", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult<LoginResult>> quickLogin(@JsonPayload() QuickLoginPayload payload);

    /**
     * 判断用户是否设置密码
     *
     * @return 请求上下文环境
     */
    @Url(value = "/my/passwd", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<Boolean>> isSetPassword();


    /**
     * 获取我的积分
     *
     * @return
     */
    @Url(value = "/my/points", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<MyPointResult>> getMyPoints();

    /**
     * 我的积分列表
     *
     * @param type 积分类型
     *             - 1:获取
     *             - 2:使用
     *             - 3:过期失效
     * @param page 页码
     * @param size 页码大小
     * @return
     */
    @Url(value = "/my/points/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<MyPointDetailListResult>> getMyPointsList(@RequestParam("type") int type,
                                                                                @PathVariable("page") int page,
                                                                                @RequestParam("size") int size);

    /**
     * 获取客服列表
     *
     * @return
     */
    @Url(value = "/services/list", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<List<CustomerServiceResult>>> getCustomerServiceList();

    //--------- 太极跑教练 start ------------

    /**
     * 开通分会
     *
     * @param name     分会名
     * @param desc     分会简介
     * @param pictures 简介图片
     * @return
     */
    @Url(value = "/my/branchs", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> openBranch(@JsonPayload("name") String name,
                                                  @JsonPayload("desc") String desc,
                                                  @JsonPayload("pictures") List<String> pictures);

    /**
     * 修改分会
     *
     * @param name
     * @param desc
     * @param pictures
     * @return
     */
    @Url(value = "/my/branchs", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult> updateBranch(@JsonPayload("name") String name,
                                                    @JsonPayload("desc") String desc,
                                                    @JsonPayload("pictures") List<String> pictures);

    /**
     * 获取分会信息
     *
     * @return
     */
    @Url(value = "/my/branchs", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<BranchResult>> getBranch();

    /**
     * 分会成员/申请加入/申请退出列表
     *
     * @param type - joined:成员
     *             - apply:申请加入
     *             - leave:申请退出
     * @param page
     * @param size
     * @return
     */
    @Url(value = "/my/branchs/{type}/members/list/{page}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<CoachListResult>> getBranchMemberList(@PathVariable("type") String type,
                                                                            @PathVariable("page") int page,
                                                                            @RequestParam("size") int size);

    /**
     * 获取教练信息和统计
     * @param id
     * @return
     */
    @Url(value = "/coachs/{id}", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<CoachResult>> getCoachInfo(@PathVariable("id") String id);

    /**
     * 获取教练信息和统计(教练本人)
     * @return
     */
    @Url(value = "/my/coachs/stat", method = RequestMethod.GET)
    CloudRequestContext<RestfulResult<CoachResult>> getMyCoachInfo();

    /**
     * 申请加入分会
     *
     * @param id
     * @return
     */
    @Url(value = "/branchs/{id}/apply", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> applyBranch(@PathVariable("id") String id);
    /**
     * 同意/拒绝加入分会(会长)
     *
     * @param id
     * @param accept
     * @return
     */
    @Url(value = "/my/branchs/coach/{id}/apply/handle", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> handleApplyBranch(@PathVariable("id") String id,
                                                         @JsonPayload("accept") boolean accept);

    /**
     * 申请退出分会
     *
     * @param distributor_id
     * @param desc
     * @return
     */
    @Url(value = "/my/branchs/coach/leave", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> leaveBranch(@JsonPayload("distributor_id") String distributor_id,
                                                   @JsonPayload("desc") String desc);


    /**
     * 同意/拒绝退出分会(会长)
     *
     * @param id
     * @param accept
     * @return
     */
    @Url(value = "/my/branchs/coach/{id}/leave/handle", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> handleLeaveBranch(@PathVariable("id") String id,
                                                         @JsonPayload("accept") boolean accept);

    /**
     * 移除会员(会长)
     *
     * @param id
     * @return
     */
    @Url(value = "/my/branchs/coach/{id}/remove", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> removeBranchMember(@PathVariable("id") String id);


    /**
     * 解散分会(会长)
     *
     * @return
     */
    @Url(value = "/my/branchs/disband", method = RequestMethod.POST)
    CloudRequestContext<RestfulResult> disbandBranch();

    /**
     * 修改教练简介
     *
     * @param desc
     * @param pictures
     * @return
     */
    @Url(value = "/my/coachs/desc", method = RequestMethod.PUT)
    CloudRequestContext<RestfulResult> updateCoachDesc(@JsonPayload("desc") String desc,
                                                       @JsonPayload("pictures") List<String> pictures);

    //--------- 太极跑教练 end ------------

}
