package hk.advanpro.cloud.api.options;

import hk.advanpro.cloud.api.callback.ResponseErrorCallback;
import hk.advanpro.cloud.api.callback.ResponseFailureCallback;
import hk.advanpro.cloud.api.callback.ResponseSuccessCallback;
import hk.advanpro.cloud.api.interceptor.RequestInterceptor;
import hk.advanpro.cloud.api.interceptor.ResponseInterceptor;

/**
 * 请求参数定义选项。
 * Created by yejianfei on 2017/8/14.
 */

public class ParameterOptions implements Cloneable {

    public static final String JSON_PAYLOAD = "JSON_PAYLOAD";

    public static final String FROM_PAYLOAD = "FROM_PAYLOAD";

    public static final String FILE_PAYLOAD = "FILE_PAYLOAD";

    public static final String STRING_PAYLOAD = "STRING_PAYLOAD";

    public static final String PATH = "PATH";

    public static final String PARAM = "PARAM";

    public static final String HEADER = "HEADER";

    public static final String RESPONSE = "RESPONSE";

    public static final int TYPE = 0;

    public static final int METHOD = 1;

    public static final int PARAMETER = 2;

    private int index;

    private String type;

    private String name;

    private String value;

    private RequestInterceptor requestInterceptor;

    private ResponseInterceptor responseInterceptor;

    private ResponseFailureCallback failureCallback;

    private ResponseErrorCallback errorCallback;

    private boolean root;

    private int target;

    public ParameterOptions() {
    }

    public ParameterOptions(int index, String type, String name, int target) {
        this.index = index;
        this.type = type;
        this.name = name;
        this.target = target;
    }

    public ParameterOptions(int index, String type, String name, boolean root, int target) {
        this.index = index;
        this.type = type;
        this.name = name;
        this.root = root;
        this.target = target;
    }

    public ParameterOptions(int index, String type, String name, String value, boolean root, int target) {
        this.index = index;
        this.type = type;
        this.name = name;
        this.value = value;
        this.root = root;
        this.target = target;
    }

    public ParameterOptions(int index, String type, String name, String value, int target) {
        this.index = index;
        this.type = type;
        this.name = name;
        this.value = value;
        this.target = target;

    }

    public ParameterOptions(int index, String type, String name, String value, RequestInterceptor requestInterceptor, int target) {
        this.index = index;
        this.type = type;
        this.name = name;
        this.value = value;
        this.requestInterceptor = requestInterceptor;
        this.target = target;
    }

    public ParameterOptions(String type, ResponseInterceptor responseInterceptor, ResponseFailureCallback failureCallback, ResponseErrorCallback errorCallback, int target) {
        this.type = type;
        this.responseInterceptor = responseInterceptor;
        this.failureCallback = failureCallback;
        this.errorCallback = errorCallback;
        this.target = target;
    }

    public int getIndex() {
        return index;
    }

    public void setIndex(int index) {
        this.index = index;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getValue() {
        return value;
    }

    public void setValue(String value) {
        this.value = value;
    }

    public RequestInterceptor getRequestInterceptor() {
        return requestInterceptor;
    }

    public void setRequestInterceptor(RequestInterceptor requestInterceptor) {
        this.requestInterceptor = requestInterceptor;
    }

    public ResponseInterceptor getResponseInterceptor() {
        return responseInterceptor;
    }

    public void setResponseInterceptor(ResponseInterceptor responseInterceptor) {
        this.responseInterceptor = responseInterceptor;
    }

    public ResponseFailureCallback getFailureCallback() {
        return failureCallback;
    }

    public void setFailureCallback(ResponseFailureCallback failureCallback) {
        this.failureCallback = failureCallback;
    }

    public ResponseErrorCallback getErrorCallback() {
        return errorCallback;
    }

    public void setErrorCallback(ResponseErrorCallback errorCallback) {
        this.errorCallback = errorCallback;
    }

    public boolean isRoot() {
        return root;
    }

    public void setRoot(boolean root) {
        this.root = root;
    }

    public int getTarget() {
        return target;
    }

    public void setTarget(int target) {
        this.target = target;
    }

    @Override
    protected ParameterOptions clone() throws CloneNotSupportedException {
        ParameterOptions options = new ParameterOptions();

        options.setIndex(getIndex());
        options.setType(getType());
        options.setName(getName());
        options.setValue(getValue());
        options.setRequestInterceptor(getRequestInterceptor());
        options.setRoot(isRoot());
        options.setTarget(getTarget());

        return options;
    }
}
