package hk.advanpro.cloud.api.options;

import org.apache.commons.lang3.StringUtils;

import java.util.ArrayList;
import java.util.List;

/**
 * 请求定义选项。
 * Created by yejianfei on 2017/8/14.
 */

public class RequestOptions implements Cloneable {

    public static RequestOptions merge(RequestOptions...options) {
        try {
            RequestOptions o = options[0].clone();

            for (int i = 1; i < options.length; i++) {
                if (StringUtils.isNotBlank(options[i].getUrl())) {
                    o.setUrl(options[i].getUrl());
                }

                if (StringUtils.isNotBlank(options[i].getMethod())) {
                    o.setMethod(options[i].getMethod());
                }

                for (ParameterOptions parameter : options[i].getParameters()) {
                    o.getParameters().add(parameter);
                }
            }

            return o;
        } catch (CloneNotSupportedException e) {
            throw new RuntimeException(e);
        }
    }

    private String url;

    private String method;

    private List<ParameterOptions> parameters = new ArrayList<>();

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getMethod() {
        return method;
    }

    public void setMethod(String method) {
        this.method = method;
    }

    public List<ParameterOptions> getParameters() {
        return parameters;
    }

    public void setParameters(List<ParameterOptions> parameters) {
        this.parameters = parameters;
    }

    @Override
    protected RequestOptions clone() throws CloneNotSupportedException {
        RequestOptions options = new RequestOptions();

        options.setUrl(getUrl());
        options.setMethod(getMethod());

        for (ParameterOptions parameter : getParameters()) {
            options.getParameters().add(parameter.clone());
        }

        return options;
    }
}
