package hk.advanpro.cloud.api.result;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;

import java.io.IOException;
import java.lang.reflect.Type;

import okhttp3.Response;
import okhttp3.ResponseBody;

/**
 * 用于安润普云端Restful标准结果对象的封装。
 * Created by yejianfei on 2017/8/12.
 */

public class RestfulResult<T extends Object> implements ResponseResult {

    protected Response response;

    private int code;

    private T data;

    private boolean success;

    private String msg;

    public int getCode() {
        return code;
    }

    public void setCode(int code) {
        this.code = code;
    }

    public T getData() {
        return data;
    }

    public void setData(T data) {
        this.data = data;
    }

    public boolean isSuccess() {
        return success;
    }

    public void setSuccess(boolean success) {
        this.success = success;
    }

    public String getMsg() {
        return msg;
    }

    public void setMsg(String msg) {
        this.msg = msg;
    }


    @SuppressWarnings("unchecked")
    @Override
    public void parse(Type[] types, Response response) throws Exception {
        this.response = response;

        System.out.println(String.format("--> http response code = %d ,method =%s ,url = %s ", response.code(), response.request().method(), response.request().url().toString()));
        ResponseBody body = response.body();
        if (!response.isSuccessful() || body == null) {
            if (!response.isSuccessful()) setCode(response.code());
            return;
        }

        JSONObject content = JSON.parseObject(body.string());

        System.out.println(String.format("--> http response body = %s", content.toString()));

        setCode(content.getIntValue("code"));
        setSuccess(content.getBooleanValue("success"));

        if (content.get("data") != null) {
            if (types != null && types.length == 1) {
                setData((T) content.getObject("data", types[0]));
            } else {
                setData((T) content.get("data"));
            }
        }
    }

    @Override
    public Response getResponse() {
        return this.response;
    }
}
