package hk.advanpro.cloud.api.result.ddc;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.annotation.JSONField;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 维修信息
 * Created by jason on 2019/6/19
 */
public class MaintenanceResult implements Serializable {

    /**
     * 状态流程
     * 1:申请维修  5:待寄回  10:已寄回  15:已寄回  20:待确认  25:维修中  30:已发货  35:已完成  40:已完成(已取消) 45:已完成(无法维修) 50:已完成(拒绝申请维修)
     */
    public static final int TYPE_APPLY = 1;
    public static final int TYPE_WAITING_POST = 5;
    public static final int TYPE_ALREADY_POST = 10;
    public static final int TYPE_ALREADY_POST2 = 15;
    public static final int TYPE_WAITING_CONFIRM = 20;
    public static final int TYPE_IN_MAINTENANCE = 25;
    public static final int TYPE_ALREADY_DELIVERY = 30;
    public static final int TYPE_ALREADY_COMPLETE = 35;
    public static final int TYPE_ALREADY_COMPLETE_CANCEL = 40;
    public static final int TYPE_ALREADY_COMPLETE_UNABLE = 45;
    public static final int TYPE_ALREADY_COMPLETE_REFUSE = 50;

    /**
     * 维修ID
     */
    @JSONField(name = "id")
    private String id;

    /**
     * 设备信息
     */
    @JSONField(name = "device")
    private MyDeviceResult device;

    /**
     * 故障信息
     */
    @JSONField(name = "fault")
    private Fault fault;

    /**
     * 物流信息
     */
    @JSONField(name = "logistics")
    private Logistics logistics;

    /**
     * 维修清单
     */
    @JSONField(name = "repair_order")
    private RepairOrder repairOrder;

    /**
     * 客服处理情况说明
     */
    @JSONField(name = "process_desc")
    private String processDesc;

    /**
     * 拒绝维修原因
     * - 1:彻底损坏
     * - 2:耗费时间大
     * - 3:没必要修了
     */
    @JSONField(name = "process_type")
    private int processType;

    /**
     * 状态
     */
    @JSONField(name = "status")
    private int status;

    /**
     * 操作人信息
     */
    @JSONField(name = "operator")
    private Operator operator;


    public static class Fault {
        @JSONField(name = "desc")
        private String desc;

        @JSONField(name = "photos")
        private List<String> photos;

        public String getDesc() {
            return desc;
        }

        public void setDesc(String desc) {
            this.desc = desc;
        }

        public List<String> getPhotos() {
            return photos;
        }

        public void setPhotos(List<String> photos) {
            this.photos = photos;
        }
    }

    public static class Logistics {
        /**
         * 用户物流信息(从用户寄送到官方)
         */
        @JSONField(name = "from")
        private AddressInfo from;

        /**
         * 官方物流信息(从官方寄送给用户)
         */
        @JSONField(name = "to")
        private AddressInfo to;

        public AddressInfo getFrom() {
            return from;
        }

        public void setFrom(AddressInfo from) {
            this.from = from;
        }

        public AddressInfo getTo() {
            return to;
        }

        public void setTo(AddressInfo to) {
            this.to = to;
        }
    }

    public static class AddressInfo {
        @JSONField(name = "receive_name")
        private String receiveName;

        @JSONField(name = "receive_phone")
        private String receivePhone;

        @JSONField(name = "receive_address")
        private String receiveAddress;

        @JSONField(name = "receive_province")
        private String receiveProvince;

        @JSONField(name = "receive_city")
        private String receiveCity;

        @JSONField(name = "receive_county")
        private String receiveCounty;

        @JSONField(name = "no")
        private String no;

        @JSONField(name = "logistics_company")
        private String logisticsCompany;

        public String getReceiveName() {
            return receiveName;
        }

        public void setReceiveName(String receiveName) {
            this.receiveName = receiveName;
        }

        public String getReceivePhone() {
            return receivePhone;
        }

        public void setReceivePhone(String receivePhone) {
            this.receivePhone = receivePhone;
        }

        public String getReceiveAddress() {
            return receiveAddress;
        }

        public void setReceiveAddress(String receiveAddress) {
            this.receiveAddress = receiveAddress;
        }

        public String getNo() {
            return no;
        }

        public void setNo(String no) {
            this.no = no;
        }

        public String getLogisticsCompany() {
            return logisticsCompany;
        }

        public void setLogisticsCompany(String logisticsCompany) {
            this.logisticsCompany = logisticsCompany;
        }

        public String getReceiveProvince() {
            return receiveProvince;
        }

        public void setReceiveProvince(String receiveProvince) {
            this.receiveProvince = receiveProvince;
        }

        public String getReceiveCity() {
            return receiveCity;
        }

        public void setReceiveCity(String receiveCity) {
            this.receiveCity = receiveCity;
        }

        public String getReceiveCounty() {
            return receiveCounty;
        }

        public void setReceiveCounty(String receiveCounty) {
            this.receiveCounty = receiveCounty;
        }
    }

    public static class RepairOrder {
        @JSONField(name = "bill_no")
        private String billNo;

        /**
         * 维修总报价
         */
        @JSONField(name = "total_fees")
        private float totalFees;

        /**
         * 费用明细
         * name:string:项目说明
         * type:int:类别 1:硬件故障 2:软件问题或其他
         * price:float:价格
         * desc:string:详细说明
         */
        @JSONField(name = "fee_items")
        private List<RepairFeeItem> feeItems;

        @JSONField(name = "estimated_time")
        private String estimatedTime;

        @JSONField(name = "actual_time")
        private String actualTime;

        @JSONField(name = "desc")
        private String desc;

        @JSONField(name = "order")
        private JSONObject order;

        public String getBillNo() {
            return billNo;
        }

        public void setBillNo(String billNo) {
            this.billNo = billNo;
        }

        public float getTotalFees() {
            return totalFees;
        }

        public void setTotalFees(float totalFees) {
            this.totalFees = totalFees;
        }

        public List<RepairFeeItem> getFeeItems() {
            return feeItems;
        }

        public void setFeeItems(List<RepairFeeItem> feeItems) {
            this.feeItems = feeItems;
        }

        public String getEstimatedTime() {
            return estimatedTime;
        }

        public void setEstimatedTime(String estimatedTime) {
            this.estimatedTime = estimatedTime;
        }

        public String getActualTime() {
            return actualTime;
        }

        public void setActualTime(String actualTime) {
            this.actualTime = actualTime;
        }

        public String getDesc() {
            return desc;
        }

        public void setDesc(String desc) {
            this.desc = desc;
        }

        public JSONObject getOrder() {
            return order;
        }

        public void setOrder(JSONObject order) {
            this.order = order;
        }
    }

    public static class Operator {
        /**
         * 创建者ID
         */
        @JSONField(name = "creator")
        private long creator;
        /**
         * 创建者名称
         */
        @JSONField(name = "creator_name")
        private String creatorName;
        /**
         * 创建时间
         */
        @JSONField(name = "creator_time")
        private Date creatorTime;

        public long getCreator() {
            return creator;
        }

        public void setCreator(long creator) {
            this.creator = creator;
        }

        public String getCreatorName() {
            return creatorName;
        }

        public void setCreatorName(String creatorName) {
            this.creatorName = creatorName;
        }

        public Date getCreatorTime() {
            return creatorTime;
        }

        public void setCreatorTime(Date creatorTime) {
            this.creatorTime = creatorTime;
        }
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public MyDeviceResult getDevice() {
        return device;
    }

    public void setDevice(MyDeviceResult device) {
        this.device = device;
    }

    public Fault getFault() {
        return fault;
    }

    public void setFault(Fault fault) {
        this.fault = fault;
    }

    public Logistics getLogistics() {
        return logistics;
    }

    public void setLogistics(Logistics logistics) {
        this.logistics = logistics;
    }

    public RepairOrder getRepairOrder() {
        return repairOrder;
    }

    public void setRepairOrder(RepairOrder repairOrder) {
        this.repairOrder = repairOrder;
    }

    public String getProcessDesc() {
        return processDesc;
    }

    public void setProcessDesc(String processDesc) {
        this.processDesc = processDesc;
    }

    public int getStatus() {
        return status;
    }

    public void setStatus(int status) {
        this.status = status;
    }

    public Operator getOperator() {
        return operator;
    }

    public void setOperator(Operator operator) {
        this.operator = operator;
    }

    public int getProcessType() {
        return processType;
    }

    public void setProcessType(int processType) {
        this.processType = processType;
    }
}
