package hk.advanpro.cloud.api.result.soc;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.annotation.JSONField;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 获取帖子或评论下级评论列表
 * Created by jason on 2018/7/3
 */
public class CommentsResult implements Serializable {
    /**
     * 帖子主键
     */
    @JSONField(name = "id")
    private String id;

    /**
     * 应用编码
     */
    @JSONField(name = "app_code")
    private String appCode;

    /**
     * 被转发或者被评论帖子主键
     */
    @JSONField(name = "post_id")
    private String post_id;

    /**
     * 父评论主键
     */
    @JSONField(name = "parent_id")
    private String parent_id;

    /**
     * 父评论作者主键
     */
    @JSONField(name = "parent_author")
    private Object parentAuthor;

    /**
     * 分层路径
     */
    @JSONField(name = "path")
    private String path;

    /**
     * 帖子图标
     */
    @JSONField(name = "icon")
    private String icon;

    /**
     * 帖子标题
     */
    @JSONField(name = "title")
    private String title;

    /**
     * 帖子正文
     */
    @JSONField(name = "text")
    private String text;

    /**
     * 图片
     */
    @JSONField(name = "pictures")
    private List<String> pictures;

    /**
     * 视频
     */
    @JSONField(name = "videos")
    private List<String> videos;

    /**
     * 是否匿名
     */
    @JSONField(name = "anonymous")
    private Boolean anonymous;

    /**
     * 帖子分类  - 0:文字 - 1:晒图 - 2:提问 - 3:训练
     */
    @JSONField(name = "category")
    private int category;

    /**
     * 帖子类型  - 0:原创  - 1:评论  - 2:转发
     */
    @JSONField(name = "type")
    private int type;

    /**
     * 评论等级
     */
    @JSONField(name = "level")
    private int level;

    /**
     * 发布频道
     */
    @JSONField(name = "channels")
    private List<String> channels;

    /**
     * 吉祥物留言
     */
    @JSONField(name = "message")
    private List<String> message;

    /**
     * 附加信息
     */
    @JSONField(name = "extras")
    private Extras extras;

    /**
     * 统计信息
     */
    @JSONField(name = "statistics")
    private Statistics statistics;

    /**
     * 状态 - 0:已删除  - 1:正常 - 2:被屏蔽
     */
    @JSONField(name = "status")
    private int status;

    @JSONField(name = "operator")
    private Operator operator;

    @JSONField(name = "children")
    private List<Children> children;


    /**
     * 是否点赞点赞了改帖子
     *
     * @return
     */
    public boolean isFavored() {
        if (this.getExtras() != null)
            return this.getExtras().isHasFavor();
        return false;
    }

    /**
     * 设置是否点赞
     *
     * @param isFavored
     */
    public void updateFavored(boolean isFavored) {
        if (this.getExtras() != null)
            this.getExtras().setHasFavor(isFavored);
        this.getStatistics().setFavorCount(this.getStatistics().getFavorCount() + (isFavored ? 1 : -1));
        if (isFavored && isDisslike()) {
            // 点赞，和踩互斥
            updateDisslike(false);
        }
    }

    /**
     * 是否踩了评论
     *
     * @return
     */
    public boolean isDisslike() {
        if (this.getExtras() != null)
            return this.getExtras().isHasDisslike();
        return false;
    }

    /**
     * 设置是否踩了评论
     *
     * @param isDisslike
     */
    public void updateDisslike(boolean isDisslike) {
        if (this.getExtras() != null)
            this.getExtras().setHasDisslike(isDisslike);
        this.getStatistics().setDiscountedCount(this.getStatistics().getDiscountedCount() + (isDisslike ? 1 : -1));
        if (isDisslike && isFavored()) {
            // 点赞，和踩互斥
            updateFavored(false);
        }
    }

    public static class Children implements Serializable {
        /**
         * 帖子主键
         */
        @JSONField(name = "id")
        private String id;

        /**
         * 应用编码
         */
        @JSONField(name = "app_code")
        private String appCode;

        /**
         * 被转发或者被评论帖子主键
         */
        @JSONField(name = "post_id")
        private String post_id;

        /**
         * 父评论作者主键
         */
        @JSONField(name = "parent_author")
        private String parent_author;
        /**
         * 帖子正文
         */
        @JSONField(name = "text")
        private String text;
        /**
         * 统计信息
         */
        @JSONField(name = "statistics")
        private Statistics statistics;

        @JSONField(name = "operator")
        private Operator operator;
        /**
         * 附加信息
         */
        @JSONField(name = "extras")
        private Extras extras;

        /**
         * 帖子类型  - 0:原创  - 1:评论  - 2:转发
         */
        @JSONField(name = "type")
        private int type;

        /**
         * 评论等级
         */
        @JSONField(name = "level")
        private int level;

        public String getId() {
            return id;
        }

        public void setId(String id) {
            this.id = id;
        }

        public String getAppCode() {
            return appCode;
        }

        public void setAppCode(String appCode) {
            this.appCode = appCode;
        }

        public String getPost_id() {
            return post_id;
        }

        public void setPost_id(String post_id) {
            this.post_id = post_id;
        }

        public String getParent_author() {
            return parent_author;
        }

        public void setParent_author(String parent_author) {
            this.parent_author = parent_author;
        }

        public String getText() {
            return text;
        }

        public void setText(String text) {
            this.text = text;
        }

        public Statistics getStatistics() {
            return statistics;
        }

        public void setStatistics(Statistics statistics) {
            this.statistics = statistics;
        }

        public Extras getExtras() {
            return extras;
        }

        public void setExtras(Extras extras) {
            this.extras = extras;
        }

        public int getType() {
            return type;
        }

        public void setType(int type) {
            this.type = type;
        }

        public int getLevel() {
            return level;
        }

        public void setLevel(int level) {
            this.level = level;
        }

        public Operator getOperator() {
            return operator;
        }

        public void setOperator(Operator operator) {
            this.operator = operator;
        }
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getAppCode() {
        return appCode;
    }

    public void setAppCode(String appCode) {
        this.appCode = appCode;
    }

    public String getPost_id() {
        return post_id;
    }

    public void setPost_id(String post_id) {
        this.post_id = post_id;
    }

    public String getParent_id() {
        return parent_id;
    }

    public void setParent_id(String parent_id) {
        this.parent_id = parent_id;
    }


    public String getPath() {
        return path;
    }

    public void setPath(String path) {
        this.path = path;
    }

    public String getIcon() {
        return icon;
    }

    public void setIcon(String icon) {
        this.icon = icon;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getText() {
        return text;
    }

    public void setText(String text) {
        this.text = text;
    }

    public List<String> getPictures() {
        return pictures;
    }

    public void setPictures(List<String> pictures) {
        this.pictures = pictures;
    }

    public List<String> getVideos() {
        return videos;
    }

    public void setVideos(List<String> videos) {
        this.videos = videos;
    }

    public Boolean getAnonymous() {
        return anonymous;
    }

    public void setAnonymous(Boolean anonymous) {
        this.anonymous = anonymous;
    }

    public int getCategory() {
        return category;
    }

    public void setCategory(int category) {
        this.category = category;
    }

    public int getType() {
        return type;
    }

    public void setType(int type) {
        this.type = type;
    }

    public List<String> getChannels() {
        return channels;
    }

    public void setChannels(List<String> channels) {
        this.channels = channels;
    }

    public List<String> getMessage() {
        return message;
    }

    public void setMessage(List<String> message) {
        this.message = message;
    }

    public Extras getExtras() {
        return extras;
    }

    public void setExtras(Extras extras) {
        this.extras = extras;
    }

    public Statistics getStatistics() {
        return statistics;
    }

    public void setStatistics(Statistics statistics) {
        this.statistics = statistics;
    }

    public int getStatus() {
        return status;
    }

    public void setStatus(int status) {
        this.status = status;
    }

    public Operator getOperator() {
        return operator;
    }

    public void setOperator(Operator operator) {
        this.operator = operator;
    }

    public List<Children> getChildren() {
        return children;
    }

    public void setChildren(List<Children> children) {
        this.children = children;
    }

    UserInfo userInfo;
    @JSONField(serialize = false)
    public UserInfo getUserInfo() {
        if (userInfo == null) {
            if (getParentAuthor() != null && getParentAuthor() instanceof JSONObject) {
                userInfo = ((JSONObject) getParentAuthor()).toJavaObject(UserInfo.class);
            }
        }
        return userInfo;
    }

    public Object getParentAuthor() {
        return parentAuthor;
    }

    public void setParentAuthor(Object parentAuthor) {
        this.parentAuthor = parentAuthor;
    }

    public static class Extras implements Serializable {
        @JSONField(name = "has_follow")
        boolean hasFollow;
        @JSONField(name = "has_disslike")
        boolean hasDisslike;
        @JSONField(name = "has_favor")
        boolean hasFavor;
        @JSONField(name = "has_collect")
        boolean hasCollect;

        public boolean isHasFollow() {
            return hasFollow;
        }

        public void setHasFollow(boolean hasFollow) {
            this.hasFollow = hasFollow;
        }

        public boolean isHasDisslike() {
            return hasDisslike;
        }

        public void setHasDisslike(boolean hasDisslike) {
            this.hasDisslike = hasDisslike;
        }

        public boolean isHasFavor() {
            return hasFavor;
        }

        public void setHasFavor(boolean hasFavor) {
            this.hasFavor = hasFavor;
        }

        public boolean isHasCollect() {
            return hasCollect;
        }

        public void setHasCollect(boolean hasCollect) {
            this.hasCollect = hasCollect;
        }

    }

    public static class Statistics implements Serializable {

        /**
         * 被踩次数
         */
        @JSONField(name = "discounted_count")
        private int discountedCount;

        /**
         * 分享次数
         */
        @JSONField(name = "shared_count")
        private int sharedCount;
        /**
         * 被举报次数
         */
        @JSONField(name = "reported_count")
        private int repostedCount;
        /**
         * 被点赞次数
         */
        @JSONField(name = "favored_count")
        private int favorCount;

        /**
         * 被转发次数
         */
        @JSONField(name = "reposted_count")
        private int repostCount;

        /**
         * 被评论次数
         */
        @JSONField(name = "commented_count")
        private int commentCount;
        /**
         * 被收藏次数
         */
        @JSONField(name = "collected_count")
        private int collectCount;

        public int getDiscountedCount() {
            return discountedCount;
        }

        public void setDiscountedCount(int discountedCount) {
            this.discountedCount = discountedCount;
        }

        public int getSharedCount() {
            return sharedCount;
        }

        public void setSharedCount(int sharedCount) {
            this.sharedCount = sharedCount;
        }

        public int getRepostedCount() {
            return repostedCount;
        }

        public void setRepostedCount(int repostedCount) {
            this.repostedCount = repostedCount;
        }

        public int getFavorCount() {
            return favorCount;
        }

        public void setFavorCount(int favorCount) {
            this.favorCount = favorCount;
        }

        public int getRepostCount() {
            return repostCount;
        }

        public void setRepostCount(int repostCount) {
            this.repostCount = repostCount;
        }

        public int getCommentCount() {
            return commentCount;
        }

        public void setCommentCount(int commentCount) {
            this.commentCount = commentCount;
        }

        public int getCollectCount() {
            return collectCount;
        }

        public void setCollectCount(int collectCount) {
            this.collectCount = collectCount;
        }
    }

    public static class Operator implements Serializable {
        @JSONField(name = "social_id")
        private String socialId;
        /**
         * 创建者
         */
        @JSONField(name = "creator")
        private UserInfo creator;

        /**
         * 创建时间
         */
        @JSONField(name = "create_time")
        private Date createTime;

        /**
         * 修改者
         */
        @JSONField(name = "modifier")
        private String modifier;

        /**
         * 修改者名称
         */
        @JSONField(name = "modifier_name")
        private String modifierName;

        /**
         * 修改时间
         */
        @JSONField(name = "modify_time")
        private Date modifyTime;

        public String getSocialId() {
            return socialId;
        }

        public void setSocialId(String socialId) {
            this.socialId = socialId;
        }

        public UserInfo getCreator() {
            return creator;
        }

        public void setCreator(UserInfo creator) {
            this.creator = creator;
        }

        public Date getCreateTime() {
            return createTime;
        }

        public void setCreateTime(Date createTime) {
            this.createTime = createTime;
        }

        public String getModifier() {
            return modifier;
        }

        public void setModifier(String modifier) {
            this.modifier = modifier;
        }

        public String getModifierName() {
            return modifierName;
        }

        public void setModifierName(String modifierName) {
            this.modifierName = modifierName;
        }

        public Date getModifyTime() {
            return modifyTime;
        }

        public void setModifyTime(Date modifyTime) {
            this.modifyTime = modifyTime;
        }
    }

    public int getLevel() {
        return level;
    }

    public void setLevel(int level) {
        this.level = level;
    }
}
