package hk.advanpro.cloud.api.result.soc;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.annotation.JSONField;

import org.apache.commons.lang3.StringUtils;

import java.io.Serializable;
import java.util.Date;

/**
 * 聊天关联信息
 * 单聊/群聊
 * Created by jason on 2018/7/3
 */
public class ContactsInfoResult implements Serializable {

    /**
     * 联系主键
     */
    private String id;

    @JSONField(name = "user_id")
    private String userId;

    /**
     * 联系人姓名
     */
    @JSONField(name = "contact_name")
    private String contactName;
    @JSONField(name = "contact_time")
    private Date contactTime;

    /**
     * :类型
     * - 0: 人
     * - 1: 群
     * - 2: 亲密群
     * - 3: 互动消息
     */
    private int type;

    /**
     * 配置信息
     */
    @JSONField(name = "config")
    private ChatConfigResult config;

    /**
     * 联系人信息
     * 区分单聊，群聊，被删除的群
     */
    Object contact;


    @JSONField(serialize = false)
    public String getPhoto() {
        if (getType() == 0) {
            ContactUserInfoResult userInfo = getUserInfo();
            if (userInfo != null)
                return userInfo.getPhoto();
        } else if (getType() == 1 || getType() == 2) {
            GroupInfoResult groupInfo = getGroupInfo();
            if (groupInfo != null)
                return groupInfo.getIcon();
        } else if (getType() == 3) {
            // 互动消息
            return null;
        } else if (getType() == 4) {
            // 系统消息
            return null;
        }
        return null;
    }

    /**
     * 获取显示名称
     * 如果是群，显示群名
     * 如果是人：有备注返回备注，否则返回 ContactName
     *
     * @return
     */
    @JSONField(serialize = false)
    public String getName() {
        if (getType() == 0 && getConfig() != null && StringUtils.isNotEmpty(getConfig().getNote())) {
            // 人，返回备注
            return getConfig().getNote();
        }
        if ((getType() == 1 || getType() == 2) && getGroupInfo() != null) {
            return getGroupInfo().getName();
        }
        if (StringUtils.isNotEmpty(getContactName())) {
            return getContactName();
        }
        if (getUserInfo() != null) {
            return getUserInfo().getNickName();
        }
        return "";
    }

    ContactUserInfoResult userInfo;
    GroupInfoResult groupInfo;

    /**
     * 获取单聊信息
     *
     * @return
     */
    public ContactUserInfoResult getUserInfo() {
        if (userInfo != null) {
            return userInfo;
        }
        if (type == 0 && getContact() instanceof JSONObject) {
            userInfo = ((JSONObject) getContact()).toJavaObject(ContactUserInfoResult.class);
        }
        return userInfo;
    }


    /**
     * 获取群聊信息
     *
     * @return
     */
    public GroupInfoResult getGroupInfo() {
        if (groupInfo != null) {
            return groupInfo;
        }
        if (type != 0 && getContact() != null && getContact() instanceof JSONObject) {
            groupInfo = ((JSONObject) getContact()).toJavaObject(GroupInfoResult.class);
        }
        return groupInfo;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public ChatConfigResult getConfig() {
        return config;
    }

    public void setConfig(ChatConfigResult config) {
        this.config = config;
    }

    public String getId() {

        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public int getType() {
        return type;
    }

    public void setType(int type) {
        this.type = type;
    }

    public Date getContactTime() {
        return contactTime;
    }

    public void setContactTime(Date contactTime) {
        this.contactTime = contactTime;
    }

    public String getContactName() {
        return contactName;
    }

    public void setContactName(String contactName) {
        this.contactName = contactName;
    }

    public Object getContact() {
        return contact;
    }

    public void setContact(Object contact) {
        this.contact = contact;
    }
}
