package hk.advanpro.cloud.api;

import com.alibaba.fastjson.JSON;

import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import java.util.concurrent.CountDownLatch;

import hk.advanpro.cloud.api.callback.ResponseErrorCallback;
import hk.advanpro.cloud.api.callback.ResponseFailureCallback;
import hk.advanpro.cloud.api.callback.ResponseSuccessCallback;
import hk.advanpro.cloud.api.client.AdminApi;
import hk.advanpro.cloud.api.client.DDCApi;
import hk.advanpro.cloud.api.client.OSSApi;
import hk.advanpro.cloud.api.client.UCApi;
import hk.advanpro.cloud.api.interceptor.ResponseInterceptor;
import hk.advanpro.cloud.api.payload.MyFeedbackPayload;
import hk.advanpro.cloud.api.result.RestfulResult;
import hk.advanpro.cloud.api.result.uc.LoginResult;
import okhttp3.Call;
import okhttp3.Response;

import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

/**
 * Created by jalin on 2017/12/22.
 */

public class AdminTest {
    public static final String formatUTCString = "yyyy-MM-dd'T'HH:mm:ss.SSS'Z'";
    private static String agent = "Unifit/3.2.0 rev 70566 (motorolaXT1085) android/5.1 (TA004043UE)";
    private static String adminUrl = "http://test.unifitapp.com/admin/api/1.0";
    private LoginResult loginResult;
    private static String token;
    private static AdminApi api;

    public static class TokenInterceptor implements ResponseInterceptor {
        @Override
        public void invoke(Call call, Response response, Throwable throwable) {
            if (response.header("Authorization") != null && !response.header("Authorization").isEmpty()) {
                token = response.header("Authorization").toString();
            }
        }
    }

    @Test
    public void before() throws Exception {
        CloudApiManager.addHeader("User-Agent", agent);
        CloudApiManager.addResponseInterceptor(new AdminTest.TokenInterceptor());
        CloudApiManager.register(AdminApi.class, adminUrl);
        api = CloudApiManager.create(AdminApi.class);

        RestfulResult<LoginResult> rs = api.login("zhouxiaolin", "密码").await();

        assertTrue(rs.getResponse().isSuccessful());
        assertTrue(rs.getCode() == 200);
        assertNotNull(JSON.toJSONString(rs.getData(), true));
    }

    //添加用户反馈请求接口
    @Test
    public void addMyFeedbacks() throws Exception {
        MyFeedbackPayload payload = new MyFeedbackPayload();
        payload.setContact("测试");
        payload.setContactWay(1);
        payload.setContent("测试");
        payload.setFirmware("1.3.2");
        RestfulResult<Boolean> rs = api.addMyFeedbacks(payload).addHeader("Authorization", token).addHeader("User-Agent", "").await();
        Assert.assertTrue(rs.getResponse().isSuccessful());
        Assert.assertTrue(rs.getCode() == 200);

        RestfulResult<String> rr = api.post("/my/feedbacks", JSON.toJSONString(payload), RestfulResult.class).addHeader("User-Agent", "").addHeader("Authorization", token).await();
        Assert.assertFalse(rr.isSuccess());
        Assert.assertTrue(rr.getCode() == 200);

        final CountDownLatch latch = new CountDownLatch(1);
        api.addMyFeedbacks(payload)
                .addHeader("Authorization", token)
                .addHeader("User-Agent", "")
                .onFailure(new ResponseFailureCallback<RestfulResult>() {
                    @Override
                    public void call(Throwable throwable, RestfulResult res) {
                        Assert.assertTrue(false);
                        latch.countDown();
                    }
                })
                .onSuccess(new ResponseSuccessCallback<RestfulResult<LoginResult>>() {
                    @Override
                    public void call(RestfulResult<LoginResult> res) {
                        Assert.assertTrue(res.getResponse().isSuccessful());
                        Assert.assertTrue(res.getCode() == 200);
                        latch.countDown();
                    }
                })
                .exec();

        latch.await();
    }
}
