package hk.advanpro.cloud.api;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.TypeReference;

import org.junit.Test;

import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.CountDownLatch;

import hk.advanpro.cloud.api.callback.ResponseFailureCallback;
import hk.advanpro.cloud.api.callback.ResponseSuccessCallback;
import hk.advanpro.cloud.api.client.CloudApi;
import hk.advanpro.cloud.api.client.UCApi;
import hk.advanpro.cloud.api.interceptor.RequestInterceptor;
import hk.advanpro.cloud.api.options.ParameterOptions;
import hk.advanpro.cloud.api.result.ResponseResult;
import hk.advanpro.cloud.api.result.RestfulResult;
import hk.advanpro.cloud.api.result.uc.LoginResult_v1;
import okhttp3.Request;
import okhttp3.Response;

/**
 * 云端接口管理器测试用例
 * Created by yejianfei on 2017/8/12.
 */

public class CloudApiManagerTest {

    public static class RequestUserAgentInterceptor implements RequestInterceptor {


        @Override
        public void invoke(int type, Request.Builder builder, ParameterOptions options, Object args) {
            if (RequestInterceptor.HEADER == type) {
                builder.addHeader(options.getName(), "xxx");
            }

        }
    }


    @Test
    public void testCreate() throws Exception {

        CloudApiManager.addHeader("xxx", "xxx");
        CloudApiManager.addHeader("User-Agent", new RequestUserAgentInterceptor());
        CloudApiManager.register(UCApi.class, "http://test.unifitapp.com/uc/api/1.0");

        CloudApi cloudApi = CloudApiManager.create("http://test.unifitapp.com/uc/api/1.0");


        UCApi api = CloudApiManager.create(UCApi.class);

        RestfulResult<LoginResult_v1> rs = api.login("18607566604", "billy2916").await();
        if (rs.getResponse().isSuccessful()) {
            System.out.println(JSON.toJSONString(rs.getData(), true));
        }

        Map<String, String> m = new HashMap<>();
        m.put("account", "18607566604");
        m.put("passwd", "billy2916");
        m.put("lang", "en");

        // RestfulResult rr = api.post("/login", JSON.toJSONString(m), RestfulResult.class).await();
        RestfulResult rr = cloudApi.post("/login", JSON.toJSONString(m), RestfulResult.class)
                .header("yyy", "yyy").await();
        System.out.println(rr.getData());

        final CountDownLatch latch = new CountDownLatch(1);
        api.login("18607566604", "billy2916")
                .onFailure(new ResponseFailureCallback() {
                    @Override
                    public void call(Throwable throwable, ResponseResult res) {

                    }
                })
                .onSuccess(new ResponseSuccessCallback<RestfulResult<LoginResult_v1>>() {
                    @Override
                    public void call(RestfulResult<LoginResult_v1> res) {
                        System.out.println(JSON.toJSONString(res.getData(), true));
                        latch.countDown();
                    }
                })
                .exec();

        latch.await();

    }
}
