package hk.advanpro.cloud.api;

import com.alibaba.fastjson.JSON;

import org.apache.commons.lang3.time.DateFormatUtils;
import org.junit.Before;
import org.junit.Test;

import java.io.File;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

import hk.advanpro.cloud.api.client.DDCApi;
import hk.advanpro.cloud.api.client.OSSApi;
import hk.advanpro.cloud.api.client.UCApi;
import hk.advanpro.cloud.api.interceptor.ResponseInterceptor;
import hk.advanpro.cloud.api.result.RestfulResult;
import hk.advanpro.cloud.api.result.ddc.AppDataResult;
import hk.advanpro.cloud.api.result.uc.LoginResult;
import hk.advanpro.cloud.api.result.uc.LoginResult_v1;
import okhttp3.Call;
import okhttp3.Response;

import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

/**
 * Created by jalin on 2017/9/20.
 */

public class DDCApiTest {
    public static final String formatUTCString = "yyyy-MM-dd'T'HH:mm:ss.SSS'Z'";
    private static String agent = "Unifit/3.2.0 rev 70566 (motorolaXT1085) android/5.1 (TA004043UE)";

    private static String ucUrl = "http://test.unifitapp.com/uc/api/1.0";
    private static String ddcUrl = "http://test.unifitapp.com/ddc/api/1.0";
    private static String ossUrl = "http://oss.test.unifitapp.com";
    private static UCApi ucApi;
    private static DDCApi ddcApi;
    private static OSSApi ossApi;
    private static String token;

    private LoginResult loginResult;

    public static class TokenInterceptor implements ResponseInterceptor {
        @Override
        public void invoke(Call call, Response response, Throwable throwable) {
            if (response.header("Authorization") != null && !response.header("Authorization").isEmpty()) {
                token = response.header("Authorization").toString();
            }
        }
    }


    @Before
    public void before() throws Exception {
        CloudApiManager.addHeader("User-Agent", agent);
        CloudApiManager.addResponseInterceptor(new TokenInterceptor());
        CloudApiManager.register(UCApi.class, ucUrl);
        CloudApiManager.register(DDCApi.class, ddcUrl);
        CloudApiManager.register(OSSApi.class, ossUrl);
        ucApi = CloudApiManager.create(UCApi.class);
        ddcApi = CloudApiManager.create(DDCApi.class);
        ossApi = CloudApiManager.create(OSSApi.class);

        RestfulResult<LoginResult_v1> rs = ucApi.login("15989781572", "123456").await();

        assertTrue(rs.getResponse().isSuccessful());
        assertTrue(rs.getCode() == 200);
        assertNotNull(JSON.toJSONString(rs.getData(), true));
    }

    @Test
    public void testOssInfo() {
        RestfulResult datas = null;
        try {
            datas = ossApi.getFilePathOssInfo("clouds").addHeader("Authorization", token).await();
        } catch (Exception e) {
            e.printStackTrace();
        }
        assertTrue(datas.isSuccess());

    }

    @Test
    public void testOssPutPhoto() {
        RestfulResult datas = null;
        try {
            File file = new File("D://test_photo.png");
            datas = ossApi.uploadProfile("durable", file).addHeader("Authorization", token).await();
        } catch (Exception e) {
            e.printStackTrace();
        }
        assertTrue(datas.isSuccess());
    }

    @Test
    public void testMyDevices() {
        RestfulResult datas = null;
        try {
            datas = ddcApi.getMyDevices()
                    .addHeader("Authorization", token).await();
        } catch (Exception e) {
            e.printStackTrace();
        }
        assertTrue(datas.isSuccess());

    }

    @Test
    public void testCheckDeviceBind() {

        RestfulResult datas = null;
        try {
            datas = ddcApi.checkDeviceBind(new String[]{"SIS01DP11700000399", "SIS01DP11700000370"})
                    .addHeader("Authorization", token).await();
        } catch (Exception e) {
            e.printStackTrace();
        }
        assertTrue(datas.isSuccess());
    }


    @Test
    public void testBindDevice() {

        RestfulResult datas = null;
        try {
            datas = ddcApi.bindDevice(new String[]{"SIS01DP11700000399", "SIS01DP11700000370"}, false)
                    .addHeader("Authorization", token).await();
        } catch (Exception e) {
            e.printStackTrace();
        }
        assertTrue(datas.isSuccess());
    }

    @Test
    public void testUnBindDevice() {
        RestfulResult datas = null;
        try {
            datas = ddcApi.unbindDevice(new String[]{"SIS01DP11700000399", "SIS01DP11700000370"})
                    .addHeader("Authorization", token).await();
        } catch (Exception e) {
            e.printStackTrace();
        }
        assertTrue(datas.isSuccess());
    }

    @Test
    public void testGetDeviceInfo() {

        RestfulResult datas = null;
        try {
            datas = ddcApi.getDeviceInfo("SIS01DP11700000399")
                    .addHeader("Authorization", token).await();
        } catch (Exception e) {
            e.printStackTrace();
        }
        assertTrue(datas.isSuccess());
    }

    @Test
    public void testGetDevPermission() {
        RestfulResult datas = null;
        try {
            datas = ddcApi.getDevPermission(1, 1, new int[]{1, 1, 1, 1})
                    .addHeader("Authorization", token).await();
        } catch (Exception e) {
            e.printStackTrace();
        }
        assertTrue(datas.isSuccess());
    }

    @Test
    public void testGetAppData() {
        RestfulResult<AppDataResult> appDatas = null;
        try {
            appDatas = ddcApi.getAppData(
                    "insole",
                    "activity",
                    "f77f05f1db07c9571a55762ce22d7b13")
                    .addHeader("Authorization", token).await();
        } catch (Exception e) {
            e.printStackTrace();
        }
        assertTrue(appDatas.isSuccess());

    }

    @Test
    public void testLoadAppDataList() {
        //获取结束时间
        Date dateEnd = new Date();
        //获取开始时间
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(dateEnd);
        calendar.add(Calendar.DATE, -30);
        Date dateBegin = calendar.getTime();


        RestfulResult<List<AppDataResult>> appDatas = null;
        try {
            appDatas = ddcApi.listAppData(
                    "insole", "activity",
                    DateFormatUtils.formatUTC(dateBegin, formatUTCString),
                    DateFormatUtils.formatUTC(dateEnd, formatUTCString))
                    .addHeader("Authorization", token).await();
        } catch (Exception e) {
            e.printStackTrace();
        }
        assertTrue(appDatas.isSuccess());

        for (AppDataResult appData : appDatas.getData()) {


        }


    }
}
