package hk.advanpro.cloud.api;

import com.alibaba.fastjson.JSON;

import org.apache.commons.lang3.time.DateFormatUtils;
import org.apache.commons.lang3.time.DateUtils;
import org.junit.Before;
import org.junit.Test;

import java.util.Calendar;
import java.util.Date;
import java.util.List;

import hk.advanpro.cloud.api.client.DDCApi;
import hk.advanpro.cloud.api.client.OSSApi;
import hk.advanpro.cloud.api.client.SACApi;
import hk.advanpro.cloud.api.client.UCApi;
import hk.advanpro.cloud.api.interceptor.ResponseInterceptor;
import hk.advanpro.cloud.api.result.RestfulResult;
import hk.advanpro.cloud.api.result.ddc.AppDataResult;
import hk.advanpro.cloud.api.result.uc.LoginResult;
import hk.advanpro.cloud.api.result.uc.LoginResult_v1;
import okhttp3.Call;
import okhttp3.Response;

import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

/**
 * Created by jalin on 2017/9/20.
 */

public class SACApiTest {
    public static final String formatUTCString = "yyyy-MM-dd'T'HH:mm:ss.SSS'Z'";
    private static String agent = "Unifit/3.2.0 rev 70566 (motorolaXT1085) android/5.1 (TA004043UE)";

    private static String ucUrl = "http://test.unifitapp.com/uc/api/1.0";
    private static String sacUrl = "http://test.unifitapp.com/sac/api/1.0";
    private static UCApi ucApi;
    private static SACApi sacApi;
    private static String token;

    private LoginResult loginResult;

    public static class TokenInterceptor implements ResponseInterceptor {
        @Override
        public void invoke(Call call, Response response, Throwable throwable) {
            if (response.header("Authorization") != null && !response.header("Authorization").isEmpty()) {
                token = response.header("Authorization").toString();
            }
        }
    }


    @Before
    public void before() throws Exception {
        CloudApiManager.addHeader("User-Agent", agent);
        CloudApiManager.addResponseInterceptor(new TokenInterceptor());
        CloudApiManager.register(UCApi.class, ucUrl);
        CloudApiManager.register(SACApi.class, sacUrl);
        ucApi = CloudApiManager.create(UCApi.class);
        sacApi = CloudApiManager.create(SACApi.class);

        RestfulResult<LoginResult_v1> rs = ucApi.login("15989781572", "123456").await();

        assertTrue(rs.getResponse().isSuccessful());
        assertTrue(rs.getCode() == 200);
        assertNotNull(JSON.toJSONString(rs.getData(), true));
    }

    @Test
    public void testGetWalkStepsByDaily() {
        RestfulResult datas = null;
        try {
            Date begin = DateUtils.addDays(new Date(), -30);
            Date end = new Date();
            datas = sacApi.getWalkStepsByDaily(
                    DateFormatUtils.formatUTC(begin, formatUTCString),
                    DateFormatUtils.formatUTC(end, formatUTCString))
                    .addHeader("Authorization", token).await();
        } catch (Exception e) {
            e.printStackTrace();
        }
        assertTrue(datas.isSuccess());
    }

    @Test
    public void testGetWalkStepsByMonth() {
        RestfulResult datas = null;
        try {
            Date begin = DateUtils.addMonths(new Date(), -12);
            Date end = new Date();
            datas = sacApi.getWalkStepsByMonth(
                    DateFormatUtils.formatUTC(begin, formatUTCString),
                    DateFormatUtils.formatUTC(end, formatUTCString))
                    .addHeader("Authorization", token).await();
        } catch (Exception e) {
            e.printStackTrace();
        }
        assertTrue(datas.isSuccess());
    }

    @Test
    public void testGetWalkGaits() {
        RestfulResult datas = null;
        try {
            Date begin = DateUtils.addMonths(new Date(), -30);
            Date end = new Date();
            datas = sacApi.getWalkGaits(
                    DateFormatUtils.formatUTC(begin, formatUTCString),
                    DateFormatUtils.formatUTC(end, formatUTCString))
                    .addHeader("Authorization", token).await();
        } catch (Exception e) {
            e.printStackTrace();
        }
        assertTrue(datas.isSuccess());
    }


    @Test
    public void testGetWalkSections() {
        RestfulResult datas = null;
        try {
            datas = sacApi.getWalkSections("2017-10-10T16:00:00.000Z")
                    .addHeader("Authorization", token).await();
        } catch (Exception e) {
            e.printStackTrace();
        }
        assertTrue(datas.isSuccess());
    }


    @Test
    public void testGetWalkDates() {
        RestfulResult datas = null;
        try {
            datas = sacApi.getWalkDates()
                    .addHeader("Authorization", token).await();
        } catch (Exception e) {
            e.printStackTrace();
        }
        assertTrue(datas.isSuccess());
    }

    @Test
    public void testGetRunStatistic() {
        RestfulResult datas = null;
        try {
            datas = sacApi.getRunStatistic()
                    .addHeader("Authorization", token).await();
        } catch (Exception e) {
            e.printStackTrace();
        }
        assertTrue(datas.isSuccess());
    }


    @Test
    public void testGetRunRecentTimes() {
        RestfulResult datas = null;
        try {
            datas = sacApi.getRunRecentTimes(5)
                    .addHeader("Authorization", token).await();
        } catch (Exception e) {
            e.printStackTrace();
        }
        assertTrue(datas.isSuccess());
    }
}
