package hk.advanpro.cloud.api;

import com.alibaba.fastjson.JSON;

import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import java.util.HashMap;
import java.util.List;
import java.util.concurrent.CountDownLatch;

import hk.advanpro.cloud.api.callback.ResponseFailureCallback;
import hk.advanpro.cloud.api.callback.ResponseSuccessCallback;
import hk.advanpro.cloud.api.client.UCApi;
import hk.advanpro.cloud.api.interceptor.RequestInterceptor;
import hk.advanpro.cloud.api.interceptor.ResponseInterceptor;
import hk.advanpro.cloud.api.options.ParameterOptions;
import hk.advanpro.cloud.api.payload.PutMyProfilePayload;
import hk.advanpro.cloud.api.payload.UserRegisterPayload;
import hk.advanpro.cloud.api.result.ResponseResult;
import hk.advanpro.cloud.api.result.RestfulResult;
import hk.advanpro.cloud.api.result.uc.AccountAuthResult;
import hk.advanpro.cloud.api.result.uc.LoginResult;
import hk.advanpro.cloud.api.result.uc.GetMyProfileResult;
import okhttp3.Call;
import okhttp3.Request;
import okhttp3.Response;

/**
 * Created by yibin on 2017/8/15.
 */

public class UCApiTest {

    public static final String user_agent = "advanpro-laf-app/1.0.0 (iphone6s) ios/10.1.2 (599F9C00-92DC-4B5C-9464-7971F01F8379)";
    /**
     * （开发环境）接口服务地址：https://dev.advanpro.cn/api/uc/2.0
     * （测试环境）接口服务地址：http://uc.test.unifitapp.com/api/2.0
     */
    public static final String ucUrl = "https://dev.advanpro.cn/api/uc/2.0";

    public static final String accountPhone = "18575607626";
    public static final String accountPassword = "KaS9JFtmcID8THFc";
    public static final String appCode = "";
    public static final int accountType = 1;


    private UCApi api;
    private static String token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJ1aWQiOiIxOTY4NzAyMjU2Mjk2Nzk2MTYiLCJvaWQiOiIxOTY4NzEwMDkzMzk1NzYzMjAiLCJ0aWQiOiIxOTY4NzEwMTc2MTQ5MzgxMTIiLCJzbm8iOiIxOTY4NzAxODk3MDk2NjAxNjAiLCJhcHAiOiJhZHZhbnByby1sYWYtYXBwIiwibmFtZSI6IuWuiea2puaZruS6p-WTgei_kOiQpeacjeWKoeWPt-euoeeQhuWRmCIsImFjY291bnQiOiIxODU3NTYwNzYyNiIsImlzcyI6ImxhZi5hZHZhbnByby5jbiIsImlhdCI6MTUyNzQ5MzkzMjkyNSwiZXhwIjoxNTMwMDg1OTMyOTI1fQ.aUVRajinv8QDrNut1sqq5_EwloVh23pLuWXIBjU-NdM";

    public static class TokenInterceptor implements ResponseInterceptor {
        @Override
        public void invoke(Call call, Response response, Throwable throwable) {
            if (response.header("Authorization") != null && !response.header("Authorization").isEmpty()) {
                token = response.header("Authorization").toString();
            }
        }
    }

    public static class UserAgentInterceptor implements RequestInterceptor {
        @Override
        public void invoke(int type, Request.Builder builder, ParameterOptions options, Object args) {
            if (type == RequestInterceptor.HEADER) {
                builder.addHeader(options.getName(), user_agent);
            }
        }
    }

    @Before
    public void before() throws Exception {
        CloudApiManager.addHeader("X-User-Agent", new UserAgentInterceptor());
        CloudApiManager.addResponseInterceptor(new TokenInterceptor());
        CloudApiManager.register(UCApi.class, ucUrl);
        api = CloudApiManager.create(UCApi.class);
//        api.login(accountPhone, accountPassword, 0).await();
    }

    //用户登录请求接口
    @Test
    public void testLoginV1() throws Exception {
//        RestfulResult<LoginResult_v1> rs = api.login(accountPhone, accountPassword).await();
//        Assert.assertTrue(rs.getResponse().isSuccessful());
//        Assert.assertTrue(rs.getCode() == 200);
//        Assert.assertNotNull(JSON.toJSONString(rs.getData(), true));
//
//        Map<String, String> m = new HashMap<>();
//        m.put("account", accountPhone);
//        m.put("passwd", accountPassword);
//        RestfulResult rr = api.post("/login", JSON.toJSONString(m), RestfulResult.class).await();
//        Assert.assertTrue(rr.isSuccess());
//        Assert.assertTrue(rr.getCode() == 200);
//        Assert.assertNotNull(rr.getData());

        final CountDownLatch latch = new CountDownLatch(1);
        api.login(accountPhone, accountPassword)
                .onFailure(new ResponseFailureCallback() {
                    @Override
                    public void call(Throwable throwable, ResponseResult res) {
                        Assert.assertTrue(false);
                        System.out.print("success");
                        latch.countDown();
                    }
                })
                .onSuccess(new ResponseSuccessCallback<RestfulResult<LoginResult>>() {
                    @Override
                    public void call(RestfulResult<LoginResult> res) {
                        Assert.assertTrue(res.getResponse().isSuccessful());
                        Assert.assertTrue(res.getCode() == 200);
                        Assert.assertNotNull(JSON.toJSONString(res.getData(), true));
                        System.out.print("success");
                        latch.countDown();
                    }
                })
                .exec();

        latch.await();

    }

    @Test
    public void testLoginV2() throws Exception {
        RestfulResult<LoginResult> rs = api.login(accountPhone, accountPassword, 0,"").await();
        Assert.assertTrue(rs.getResponse().isSuccessful());
        Assert.assertTrue(rs.getCode() == 200);
        Assert.assertNotNull(JSON.toJSONString(rs.getData(), true));

    }

    //获取验证码请求接口
    @Test
    public void testVcode() throws Exception {
        RestfulResult<String> rs = api.sendVCode(accountPhone, accountType, "zh_CN").await();
        Assert.assertTrue(rs.isSuccess());
    }

    //注册账号请求接口
    @Test
    public void registerTest() throws Exception {
        UserRegisterPayload userRegisterPayload = new UserRegisterPayload();
        userRegisterPayload.setAccount("15989781572");
        userRegisterPayload.setAccountType(1);
        userRegisterPayload.setPasswd("123456");
        userRegisterPayload.setVcode("125275");
        RestfulResult rs = api.register(userRegisterPayload).await();
        Assert.assertTrue(rs.getResponse().isSuccessful());
        Assert.assertTrue(rs.getCode() == 20505);

        RestfulResult rr = api.post("/register", JSON.toJSONString(userRegisterPayload), RestfulResult.class).await();
        Assert.assertTrue(!rr.isSuccess());
        Assert.assertTrue(rr.getCode() == 20505);
    }

    //发送验证码
    @Test
    public void setVcodeTest() throws Exception {
        RestfulResult<Boolean> rs = api.sendVCode("15989781572", 1, "zh_CN").await();
        Assert.assertTrue(rs.getResponse().isSuccessful());
        Assert.assertTrue(rs.getCode() == 200);
        Assert.assertTrue(!rs.getData());
    }

    // 检查验证码是否正确
    @Test
    public void checkVCodeTest() throws Exception {
        RestfulResult rs = api.checkVCode("503754", "15989781572").await();
        Assert.assertTrue(rs.getResponse().isSuccessful());
        Assert.assertTrue(rs.getCode() == 200);
    }

    //忘记密码请求接口
    @Test
    public void forgotTest() throws Exception {
        RestfulResult<String> rs = api.forgot("15989781572", "123456", "164236").await();
        Assert.assertTrue(rs.getResponse().isSuccessful());
        Assert.assertTrue(rs.getCode() == 20505);

    }

    //判断用户是否存在请求接口
    @Test
    public void accountExistTest() throws Exception {
        RestfulResult<Boolean> rs = api.isWxExists("158205874041582058740415820587404").await();
        Assert.assertTrue(rs.getResponse().isSuccessful());
        Assert.assertTrue(rs.getCode() == 200);
        Assert.assertNotNull(JSON.toJSONString(rs.getData(), true));

    }

    //获取登录用户基本信息请求接口
    @Test
    public void getMyProfile() throws Exception {
        RestfulResult<GetMyProfileResult> rs = api.getMyProfile().await();
        Assert.assertTrue(rs.getResponse().isSuccessful());
        Assert.assertTrue(rs.getCode() == 200);
        Assert.assertNotNull(JSON.toJSONString(rs.getData(), true));

        RestfulResult<GetMyProfileResult> rr = api.get("/my/profiles", RestfulResult.class).await();
        Assert.assertTrue(rr.isSuccess());
        Assert.assertTrue(rr.getCode() == 200);
        Assert.assertNotNull(rr.getData());
    }

    //设置登录用户基本信息请求接口
    @Test
    public void putMyProfile() throws Exception {
        PutMyProfilePayload putMyProfilePayload = new PutMyProfilePayload();
        putMyProfilePayload.setNickName("test");
        putMyProfilePayload.setAge(21);
        putMyProfilePayload.setBirthday("1992-01-01");
        putMyProfilePayload.setHeight(172);
        putMyProfilePayload.setWeight(60);
        putMyProfilePayload.setSex("M");
        RestfulResult<PutMyProfilePayload> result2 = api.setMyProfile(putMyProfilePayload).addHeader("Authorization", token).await();
        Assert.assertTrue(result2.getResponse().isSuccessful());
        Assert.assertTrue(result2.getCode() == 200);

        RestfulResult<GetMyProfileResult> result = api.put("/my/profile", JSON.toJSONString(putMyProfilePayload), RestfulResult.class).addHeader("Authorization", token).await();
        Assert.assertTrue(result.isSuccess());

    }

    //修改登录密码请求接口
    @Test
    public void changeMyPasswd() throws Exception {
        RestfulResult<String> rs = api.changeMyPasswd("123456", "123456").addHeader("Authorization", token).await();
        Assert.assertTrue(rs.getResponse().isSuccessful());
        Assert.assertTrue(rs.getCode() == 20503);

        HashMap<String, String> params = new HashMap<>();
        params.put("passwd", "123456");
        params.put("new_passwd", "123456");
        RestfulResult<GetMyProfileResult> rr = api.put("/my/passwd", JSON.toJSONString(params), RestfulResult.class).addHeader("Authorization", token).await();
        Assert.assertFalse(rr.isSuccess());
    }

    //获取绑定账号列表请求接口
    @Test
    public void accountAuthsList() throws Exception {
        RestfulResult<List<AccountAuthResult>> rs = api.accountAuthsList().await();
        Assert.assertTrue(rs.getResponse().isSuccessful());
        Assert.assertTrue(rs.getCode() == 200);
        Assert.assertNotNull(rs.getData());
    }

    // 绑定手机
    @Test
    public void bindPhone() throws Exception {
        RestfulResult<String> rs = api.bindPhone("15989781572", "1111", "1111111").addHeader("Authorization", token).await();
        Assert.assertTrue(rs.getResponse().isSuccessful());
        Assert.assertTrue(rs.getCode() == 200);
    }

    // 换绑手机
    @Test
    public void changePhone() throws Exception {
        RestfulResult<String> rs = api.changePhone("15989781572", "15989781572", "1111").await();
        Assert.assertTrue(rs.getResponse().isSuccessful());
        Assert.assertTrue(rs.getCode() == 200);
    }

    //解绑微信
    @Test
    public void unbindWechar() throws Exception {
        RestfulResult<String> rs = api.unbindWechar("1582058740415820587404").await();
        Assert.assertTrue(rs.getResponse().isSuccessful());
        Assert.assertTrue(rs.getCode() == 200);
    }

    //绑定微信
    @Test
    public void bindWechar() throws Exception {
        RestfulResult rs = api.bindWechar("1582058740415820587404","jalin","").await();
        Assert.assertTrue(rs.getResponse().isSuccessful());
        Assert.assertTrue(rs.getCode() == 200);
    }


}
